@@ -21,9 +21,7 @@ EXCLUDE = (
     "cmd/gvedit/csettings.h",
     "cmd/gvedit/imageviewer.cpp",
     "cmd/gvedit/imageviewer.h",
-    "cmd/gvedit/mdichild.cpp",
     "cmd/gvedit/mdichild.h",
-    "cmd/gvedit/ui_settings.h",
     "cmd/gvmap/cluster.c",
     "cmd/gvmap/country_graph_coloring.c",
     "cmd/gvmap/country_graph_coloring.h",
@@ -47,21 +45,15 @@ EXCLUDE = (
     "cmd/smyrna/gui/appmouse.c",
     "cmd/smyrna/gui/appmouse.h",
     "cmd/smyrna/gui/callbacks.c",
-    "cmd/smyrna/gui/callbacks.h",
     "cmd/smyrna/gui/datalistcallbacks.c",
-    "cmd/smyrna/gui/datalistcallbacks.h",
     "cmd/smyrna/gui/frmobjectui.c",
-    "cmd/smyrna/gui/frmobjectui.h",
     "cmd/smyrna/gui/glcompui.c",
     "cmd/smyrna/gui/glcompui.h",
     "cmd/smyrna/gui/gui.c",
     "cmd/smyrna/gui/gui.h",
     "cmd/smyrna/gui/menucallbacks.c",
-    "cmd/smyrna/gui/menucallbacks.h",
     "cmd/smyrna/gui/toolboxcallbacks.c",
-    "cmd/smyrna/gui/toolboxcallbacks.h",
     "cmd/smyrna/gui/topviewsettings.c",
-    "cmd/smyrna/gui/topviewsettings.h",
     "cmd/smyrna/gvprpipe.c",
     "cmd/smyrna/hier.c",
     "cmd/smyrna/hier.h",
@@ -186,7 +178,6 @@ EXCLUDE = (
     "lib/common/const.h",
     "lib/common/ellipse.c",
     "lib/common/emit.c",
-    "lib/common/entities.h",
     "lib/common/geom.c",
     "lib/common/geom.h",
     "lib/common/geomprocs.h",
@@ -380,11 +371,9 @@ EXCLUDE = (
     "lib/neatogen/geometry.c",
     "lib/neatogen/geometry.h",
     "lib/neatogen/heap.c",
-    "lib/neatogen/heap.h",
     "lib/neatogen/hedges.c",
     "lib/neatogen/hedges.h",
     "lib/neatogen/info.c",
-    "lib/neatogen/info.h",
     "lib/neatogen/kkutils.c",
     "lib/neatogen/kkutils.h",
     "lib/neatogen/legal.c",
@@ -423,7 +412,6 @@ EXCLUDE = (
     "lib/neatogen/stress.h",
     "lib/neatogen/stuff.c",
     "lib/neatogen/voronoi.c",
-    "lib/neatogen/voronoi.h",
     "lib/ortho/fPQ.c",
     "lib/ortho/fPQ.h",
     "lib/ortho/maze.c",
@@ -448,10 +436,8 @@ EXCLUDE = (
     "lib/patchwork/tree_map.c",
     "lib/patchwork/tree_map.h",
     "lib/pathplan/cvt.c",
-    "lib/pathplan/inpoly.c",
     "lib/pathplan/pathgeom.h",
     "lib/pathplan/pathplan.h",
-    "lib/pathplan/pathutil.h",
     "lib/pathplan/route.c",
     "lib/pathplan/shortest.c",
     "lib/pathplan/shortestpth.c",
@@ -519,9 +505,6 @@ EXCLUDE = (
     "lib/vpsc/csolve_VPSC.h",
     "lib/vpsc/generate-constraints.cpp",
     "lib/vpsc/generate-constraints.h",
-    "lib/vpsc/pairingheap/PairingHeap.cpp",
-    "lib/vpsc/pairingheap/PairingHeap.h",
-    "lib/vpsc/pairingheap/dsexceptions.h",
     "lib/vpsc/solve_VPSC.cpp",
     "lib/vpsc/solve_VPSC.h",
     "lib/vpsc/variable.cpp",
@@ -575,13 +558,6 @@ EXCLUDE = (
     "plugin/gdk/gvdevice_gdk.c",
     "plugin/gdk/gvloadimage_gdk.c",
     "plugin/gs/gvloadimage_gs.c",
-    "plugin/gtk/callbacks.c",
-    "plugin/gtk/callbacks.h",
-    "plugin/gtk/gvdevice_gtk.c",
-    "plugin/gtk/interface.c",
-    "plugin/gtk/interface.h",
-    "plugin/gtk/support.c",
-    "plugin/gtk/support.h",
     "plugin/lasi/gvrender_lasi.cpp",
     "plugin/pango/gvgetfontlist.h",
     "plugin/pango/gvgetfontlist_pango.c",
@@ -625,20 +601,6 @@ EXCLUDE = (
     "tclpkg/tclpathplan/tclpathplan.c",
     "tclpkg/tclpathplan/wrapper.c",
     "tclpkg/tclstubs/tclStubLib.c",
-    "windows/gvedit/Application.h",
-    "windows/gvedit/GraphX.cpp",
-    "windows/gvedit/UAbout.cpp",
-    "windows/gvedit/UAbout.h",
-    "windows/gvedit/UEditor.cpp",
-    "windows/gvedit/UEditor.h",
-    "windows/gvedit/UPreProcess.cpp",
-    "windows/gvedit/UPreProcess.h",
-    "windows/gvedit/UPreview.cpp",
-    "windows/gvedit/UPreview.h",
-    "windows/gvedit/USettings.cpp",
-    "windows/gvedit/USettings.h",
-    "windows/gvedit/Umain.cpp",
-    "windows/gvedit/Umain.h",
     "windows/include/unistd/unistd.h",
 )
 
@@ -671,7 +633,6 @@ sources = subprocess.check_output(
 )
 
 for source in sources.split("\x00")[:-1]:
-
     print(f"checking {source}...")
 
     original = Path(source).read_text(encoding="utf-8")
