@@ -58,6 +58,8 @@ def main(args: List[str]) -> int:  # pylint: disable=C0116
 
     # files that are generated but only need to be excluded during init
     init_generated_files = [
+        cwd / "build/tclpkg/gv/CMakeFiles/gv_d.dir/gvD_wrap.cxx",
+        cwd / "build/tclpkg/gv/CMakeFiles/gv_go.dir/gvGO_wrap.cxx",
         cwd / "build/tclpkg/gv/CMakeFiles/gv_sharp.dir/gvCSHARP_wrap.cxx",
         cwd / "build/tclpkg/gv/CMakeFiles/gv_tcl.dir/gvTCL_wrap.cxx",
     ]
