@@ -14,11 +14,12 @@
 #include <cgraph/cgraph.h>
 #include <cgraph/exit.h>
 #include <cgraph/ingraphs.h>
-#include <common/pointset.h>
 #include <getopt.h>
 #include <iomanip>
 #include <iostream>
 #include <sstream>
+#include <unordered_map>
+#include <utility>
 #include <vector>
 
 #include <sparse/DotIO.h>
@@ -97,61 +98,60 @@ checkG (Agraph_t* g)
 	return 0;
 }
 
-static void init(int argc, char *argv[], opts_t* opts)
-{
+static void init(int argc, char *argv[], opts_t &opts) {
 	int c;
 	char* cmd = argv[0];
 	double s;
 	int i;
 
 	opterr = 0;
-	opts->outer_iter = 4;
-	opts->method = METHOD_INK_AGGLOMERATE;
-	opts->compatibility_method = COMPATIBILITY_FULL;
-	opts->K = -1;
-	opts->fmt = FMT_GV;
-	opts->nneighbors = 10;
-	opts->max_recursion = 100;
-	opts->angle_param = -1;
-	opts->angle = 40.0/180.0*M_PI;
+	opts.outer_iter = 4;
+	opts.method = METHOD_INK_AGGLOMERATE;
+	opts.compatibility_method = COMPATIBILITY_FULL;
+	opts.K = -1;
+	opts.fmt = FMT_GV;
+	opts.nneighbors = 10;
+	opts.max_recursion = 100;
+	opts.angle_param = -1;
+	opts.angle = 40.0/180.0*M_PI;
 
 	while ((c = getopt(argc, argv, ":a:c:i:k:K:m:o:p:r:T:v:?")) != -1) {
 		switch (c) {
 		case 'a':
-			if ((sscanf(optarg,"%lf",&s) > 0) && (s >= 0))
-				opts->angle =  M_PI*s/180;
+			if (sscanf(optarg, "%lf", &s) > 0 && s >= 0)
+				opts.angle =  M_PI * s / 180;
 			else
 				std::cerr << "-a arg " << optarg << " must be positive real - ignored\n";
 			break;
 		case 'c':
-			if ((sscanf(optarg,"%d",&i) > 0) && (0 <= i) && (i <= COMPATIBILITY_FULL))
-				opts->compatibility_method =  i;
+			if (sscanf(optarg, "%d", &i) > 0 && 0 <= i && i <= COMPATIBILITY_FULL)
+				opts.compatibility_method =  i;
 			else
 				std::cerr << "-c arg " << optarg << " must be an integer in [0,"
 					<< COMPATIBILITY_FULL << "] - ignored\n";
 			break;
 		case 'i':
-			if ((sscanf(optarg,"%d",&i) > 0) && (i >= 0))
-				opts->outer_iter =  i;
+			if (sscanf(optarg, "%d", &i) > 0 && i >= 0)
+				opts.outer_iter =  i;
 			else
 				std::cerr << "-i arg " << optarg << " must be a non-negative integer - "
 					"ignored\n";
 			break;
 		case 'k':
-			if ((sscanf(optarg,"%d",&i) > 0) && (i >= 2))
-				opts->nneighbors =  i;
+			if (sscanf(optarg, "%d", &i) > 0 && i >= 2)
+				opts.nneighbors =  i;
 			else
 				std::cerr << "-k arg " << optarg << " must be an integer >= 2 - ignored\n";
 			break;
 		case 'K':
-			if ((sscanf(optarg,"%lf",&s) > 0) && (s > 0))
-				opts->K =  s;
+			if (sscanf(optarg, "%lf", &s) > 0 && s > 0)
+				opts.K =  s;
 			else
 				std::cerr << "-K arg " << optarg << " must be positive real - ignored\n";
 			break;
 		case 'm':
-			if ((sscanf(optarg,"%d",&i) > 0) && (0 <= i) && (i <= METHOD_INK))
-				opts->method =  i;
+			if (sscanf(optarg, "%d", &i) > 0 && 0 <= i && i <= METHOD_INK)
+				opts.method =  i;
 			else
 				std::cerr << "-k arg " << optarg << " must be an integer >= 2 - ignored\n";
 			break;
@@ -159,30 +159,30 @@ static void init(int argc, char *argv[], opts_t* opts)
 			outfile = openFile(cmd, optarg, "w");
 			break;
 		case 'p':
-			if ((sscanf(optarg,"%lf",&s) > 0))
-				opts->angle_param =  s;
+			if (sscanf(optarg, "%lf", &s) > 0)
+				opts.angle_param =  s;
 			else
 				std::cerr << "-p arg " << optarg << " must be real - ignored\n";
 			break;
 		case 'r':
-			if ((sscanf(optarg,"%d",&i) > 0) && (i >= 0))
-				opts->max_recursion =  i;
+			if (sscanf(optarg, "%d", &i) > 0 && i >= 0)
+				opts.max_recursion =  i;
 			else
 				std::cerr << "-r arg " << optarg << " must be a non-negative integer - "
 					"ignored\n";
 			break;
 		case 'T':
 			if (!strcmp(optarg, "gv"))
-				opts->fmt = FMT_GV;
+				opts.fmt = FMT_GV;
 			else if (!strcmp(optarg,"simple"))
-				opts->fmt = FMT_SIMPLE;
+				opts.fmt = FMT_SIMPLE;
 			else
 				std::cerr << "-T arg " << optarg << " must be \"gv\" or \"simple\" - "
 					"ignored\n";
 			break;
 		case 'v':
 			Verbose = 1;
-			if ((sscanf(optarg,"%d",&i) > 0) && (i >= 0))
+			if (sscanf(optarg, "%d", &i) > 0 && i >= 0)
 				Verbose = static_cast<unsigned char>(i);
 			else
 				optind--;
@@ -216,15 +216,15 @@ static void init(int argc, char *argv[], opts_t* opts)
     if (Verbose) {
        std::cerr
          << "Mingle params:\n"
-         << "  outer_iter = " << opts->outer_iter << '\n'
-         << "  method = " << opts->method << '\n'
-         << "  compatibility_method = " << opts->compatibility_method << '\n'
-         << "  K = " << std::setprecision(2) << opts->K << '\n'
-         << "  fmt = " << (opts->fmt ? "simple" : "gv") << '\n'
-         << "  nneighbors = " << opts->nneighbors << '\n'
-         << "  max_recursion = " <<  opts->max_recursion << '\n'
-         << "  angle_param = " << std::setprecision(2) <<  opts->angle_param << '\n'
-         << "  angle = " << std::setprecision(2) << (180 * opts->angle / M_PI) << '\n';
+         << "  outer_iter = " << opts.outer_iter << '\n'
+         << "  method = " << opts.method << '\n'
+         << "  compatibility_method = " << opts.compatibility_method << '\n'
+         << "  K = " << std::setprecision(2) << opts.K << '\n'
+         << "  fmt = " << (opts.fmt ? "simple" : "gv") << '\n'
+         << "  nneighbors = " << opts.nneighbors << '\n'
+         << "  max_recursion = " <<  opts.max_recursion << '\n'
+         << "  angle_param = " << std::setprecision(2) <<  opts.angle_param << '\n'
+         << "  angle = " << std::setprecision(2) << (180 * opts.angle / M_PI) << '\n';
     }
 }
 
@@ -352,9 +352,17 @@ static void export_dot(FILE *fp, int ne, const std::vector<pedge> &edges,
 	agwrite(g, fp);
 }
 
-static int
-bundle (Agraph_t* g, opts_t* opts)
-{
+/// a hash derivation function for int pairs
+struct PointHash {
+public:
+  size_t operator()(const std::pair<int, int> &x) const {
+    return std::hash<int>{}(x.first) ^ std::hash<int>{}(x.second);
+  }
+};
+
+using PointMap = std::unordered_map<std::pair<int, int>, int, PointHash>;
+
+static int bundle(Agraph_t *g, const opts_t &opts) {
 	double *x = nullptr;
 	int dim = 2;
     int i;
@@ -376,8 +384,8 @@ bundle (Agraph_t* g, opts_t* opts)
     }
 
 	A = SparseMatrix_symmetrize(A, true);
-	if (opts->fmt == FMT_GV) {
-		PointMap* pm = newPM();    /* map from node id pairs to edge index */
+	if (opts.fmt == FMT_GV) {
+		PointMap pm; // map from node id pairs to edge index
 		Agnode_t* n;
 		Agedge_t* e;
 		int idx = 0;
@@ -387,27 +395,25 @@ bundle (Agraph_t* g, opts_t* opts)
 		for (i = 0; i < A->m; i++){
 			for (int j = ia[i]; j < ia[i+1]; j++){
 				if (ja[j] > i){
-					insertPM (pm, i, ja[j], idx++);
+					pm[std::pair(i, ja[j])] = idx++;
 				}
 			}
 		}
 		for (i = 0, n = agfstnode(g); n; n = agnxtnode(g,n)) {
 			setDotNodeID(n, i++);
 		}
-		for (i = 0, n = agfstnode(g); n; n = agnxtnode(g,n)) {
+		for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
 			for (e = agfstout (g, n); e; e = agnxtout (g, e)) {
 				i = getDotNodeID (agtail(e));
 				int j = getDotNodeID (aghead(e));
 				if (j < i) {
 					std::swap(i, j);
 				}
-				int k = insertPM (pm, i, j, -1);
-				assert (k >= 0);
+				const int k = pm[std::pair(i, j)];
 				agbindrec (e, "info", sizeof(etoi_t), true);
 				ED_idx(e) = k;
 			}
 		}
-		freePM (pm);
 	}
 		
 	const int *ia = A->ia;
@@ -430,18 +436,18 @@ bundle (Agraph_t* g, opts_t* opts)
 	if (Verbose)
 		std::cerr << "n = " << A->m << " nz = " << nz << '\n';
 
-	SparseMatrix B = nearest_neighbor_graph(nz, std::min(opts->nneighbors, nz), xx);
+	SparseMatrix B = nearest_neighbor_graph(nz, std::min(opts.nneighbors, nz), xx);
 
 	SparseMatrix_delete(A);
 	A = B;
 	free(x);
 
 	std::vector<pedge> edges =
-            edge_bundling(A, 2, xx, opts->outer_iter, opts->K, opts->method,
-                          opts->nneighbors, opts->compatibility_method,
-                          opts->max_recursion, opts->angle_param, opts->angle);
+            edge_bundling(A, 2, xx, opts.outer_iter, opts.K, opts.method,
+                          opts.nneighbors, opts.compatibility_method,
+                          opts.max_recursion, opts.angle_param, opts.angle);
 
-	if (opts->fmt == FMT_GV) {
+	if (opts.fmt == FMT_GV) {
 	    	export_dot(outfile, A->m, edges, g);
 	}
 	else {
@@ -458,7 +464,7 @@ int main(int argc, char *argv[])
 	int rv = 0;
 	opts_t opts;
 
-	init(argc, argv, &opts);
+	init(argc, argv, opts);
 	newIngraph(&ig, Files);
 
 	while ((g = nextGraph(&ig)) != 0) {
@@ -468,7 +474,7 @@ int main(int argc, char *argv[])
 		fname = fileName(&ig);
 		if (Verbose)
 		    std::cerr << "Process graph " << agnameof(g) << " in file " << fname << '\n';
-		rv |= bundle (g, &opts);
+		rv |= bundle(g, opts);
 	}
 
 	graphviz_exit(rv);
