@@ -13,29 +13,27 @@
 #include "gui.h"
 #include <cgraph/startswith.h>
 #include <common/colorprocs.h>
+#include <stdint.h>
 #include "viewport.h"
 
-void color_change_request(GtkWidget * widget, gpointer user_data)
-{
+void color_change_request(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     view->refresh.color=1;
 }
-void size_change_request(GtkWidget * widget, gpointer user_data)
-{
+
+void size_change_request(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
 
-void on_settingsOKBtn_clicked(GtkWidget * widget, gpointer user_data)
-{
+void on_settingsOKBtn_clicked(GtkWidget *widget, void *user_data) {
     on_settingsApplyBtn_clicked(widget, user_data);
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgSettings"));
 }
 
-void on_settingsApplyBtn_clicked(GtkWidget * widget, gpointer user_data)
-{
+void on_settingsApplyBtn_clicked(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -43,16 +41,15 @@ void on_settingsApplyBtn_clicked(GtkWidget * widget, gpointer user_data)
     set_viewport_settings_from_template(view, view->g[view->activeGraph]);
     updateSmGraph(view->g[view->activeGraph],view->Topview);
 }
-void on_dlgSettings_close (GtkWidget * widget, gpointer user_data)
-{
+
+void on_dlgSettings_close(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgSettings"));
 }
 
-void on_settingsCancelBtn_clicked(GtkWidget * widget, gpointer user_data)
-{
+void on_settingsCancelBtn_clicked(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -77,9 +74,9 @@ static void set_color_button_widget(char *attrib, char *widget_name) {
     }
     if (buf) {
 	colorxlate(buf, &cl, RGBA_DOUBLE);
-	color.red = (guint16)(cl.u.RGBA[0] * 65535.0);
-	color.green = (guint16)(cl.u.RGBA[1] * 65535.0);
-	color.blue = (guint16)(cl.u.RGBA[2] * 65535.0);
+	color.red = (uint16_t)(cl.u.RGBA[0] * 65535.0);
+	color.green = (uint16_t)(cl.u.RGBA[1] * 65535.0);
+	color.blue = (uint16_t)(cl.u.RGBA[2] * 65535.0);
 	gtk_color_button_set_color((GtkColorButton *)
 				   glade_xml_get_widget(xml, widget_name),
 				   &color);
