@@ -22,10 +22,6 @@
 #include <common/color.h>
 #include <common/colorprocs.h>
 
-#ifdef _WIN32
-#include <wincrypt.h>
-#endif
-
 static int get_temp_coords(topview * t, int level, int v, double *coord_x,
 			   double *coord_y);
 
@@ -317,10 +313,8 @@ static void drawtopfishedges(topview * t)
 
 static int get_active_frame(void)
 {
-    gulong microseconds;
-    gdouble seconds;
     int fr;
-    seconds = g_timer_elapsed(view->timer, &microseconds);
+    gdouble seconds = g_timer_elapsed(view->timer, NULL);
     fr = (int)(seconds * 1000.0);
     if (fr < view->total_frames) {
 
