@@ -27,15 +27,16 @@
 #include <cgraph/cghdr.h>
 #include <cgraph/exit.h>
 #include <cgraph/ingraphs.h>
-#include <cgraph/stack.h>
-#include <cgraph/startswith.h>
+#include <cgraph/list.h>
+#include <common/render.h>
+#include <common/utils.h>
 
 typedef struct {
     Agrec_t h;
     int dfs_mark;
-} Agnodeinfo_t;
+} nodeinfo_t;
 
-#define ND_dfs_mark(n) (((Agnodeinfo_t*)(n->base.data))->dfs_mark)
+#define ND_dfs_mark(n) (((nodeinfo_t*)(n->base.data))->dfs_mark)
 
 #include <getopt.h>
 
@@ -59,7 +60,7 @@ static int verbose;
 static int gtype;
 static int flags;
 static char *fname;
-static char **Files;
+static char **Inputs;
 static FILE *outfile;
 
 static char *useString = "Usage: gc [-necCaDUrsv?] <files>\n\
@@ -139,7 +140,7 @@ static void init(int argc, char *argv[])
     argc -= optind;
 
     if (argc)
-	Files = argv;
+	Inputs = argv;
     if (flags == 0)
 	flags = NODES | EDGES;
     if (gtype == 0)
@@ -147,20 +148,21 @@ static void init(int argc, char *argv[])
     outfile = stdout;
 }
 
-static gv_stack_t Stk;
+DEFINE_LIST(node_stack, Agnode_t *)
+static node_stack_t Stk;
 
 static void push(Agnode_t * np)
 {
     ND_dfs_mark(np) = -1;
-    stack_push(&Stk, np);
+    node_stack_push_back(&Stk, np);
 }
 
 static Agnode_t *pop(void)
 {
-    if (stack_is_empty(&Stk)) {
+    if (node_stack_is_empty(&Stk)) {
 	return 0;
     }
-    return stack_pop(&Stk);
+    return node_stack_pop_back(&Stk);
 }
 
 static void cc_dfs(Agraph_t * g, Agnode_t * n)
@@ -186,9 +188,7 @@ static void cntCluster(Agraph_t * g, Agobj_t * sg, void *arg)
 {
     (void)g;
 
-    char *sgname = agnameof(sg);
-
-    if (startswith(sgname, "cluster"))
+    if (AGTYPE(sg) == AGRAPH && is_a_cluster((Agraph_t *)sg))
 	*(int *) (arg) += 1;
 }
 
@@ -276,7 +276,7 @@ static int eval(Agraph_t * g, int root)
 	return 1;
 
     if (root) {
-	aginit(g, AGNODE, "nodeinfo", sizeof(Agnodeinfo_t), true);
+	aginit(g, AGNODE, "nodeinfo", sizeof(nodeinfo_t), true);
     }
 
     if ((flags & CL) && root)
@@ -301,7 +301,7 @@ int main(int argc, char *argv[])
     int rv = 0;
 
     init(argc, argv);
-    newIngraph(&ig, Files);
+    newIngraph(&ig, Inputs);
 
     while ((g = nextGraph(&ig)) != 0) {
 	if (prev)
@@ -317,7 +317,7 @@ int main(int argc, char *argv[])
     if (n_graphs > 1)
 	wcp(tot_nodes, tot_edges, tot_cc, tot_cl, "total", 0);
 
-    stack_reset(&Stk);
+    node_stack_free(&Stk);
 
     graphviz_exit(rv);
 }
