@@ -15,15 +15,18 @@
 
 
 #include    "convert.h"
+#include    <assert.h>
 #include    <cgraph/agxbuf.h>
 #include    <cgraph/alloc.h>
 #include    <cgraph/exit.h>
 #include    <cgraph/gv_ctype.h>
-#include    <cgraph/stack.h>
+#include    <cgraph/list.h>
 #include    <cgraph/unreachable.h>
 #include    <getopt.h>
+#include    <limits.h>
 #include    <stdbool.h>
 #include    <stdio.h>
+#include    <stdlib.h>
 #include    <string.h>
 #include    "openFile.h"
 #ifdef HAVE_EXPAT
@@ -48,62 +51,58 @@ static char **Files;
 static int Verbose;
 static char* gname = "";
 
-static void pushString(gv_stack_t *stk, const char *s) {
+DEFINE_LIST_WITH_DTOR(strs, char *, free)
+
+static void pushString(strs_t *stk, const char *s) {
 
   // duplicate the string we will push
   char *copy = gv_strdup(s);
 
   // push this onto the stack
-  stack_push(stk, copy);
+  strs_push_back(stk, copy);
 }
 
-static void popString(gv_stack_t *stk) {
+static void popString(strs_t *stk) {
 
-  if (stack_is_empty(stk)) {
+  if (strs_is_empty(stk)) {
     fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
     graphviz_exit(EXIT_FAILURE);
   }
 
-  char *s = stack_pop(stk);
-  free(s);
+  strs_resize(stk, strs_size(stk) - 1, NULL);
 }
 
-static char *topString(gv_stack_t *stk) {
+static char *topString(strs_t *stk) {
 
-  if (stack_is_empty(stk)) {
+  if (strs_is_empty(stk)) {
     fprintf(stderr, "PANIC: graphml2gv: empty element stack\n");
     graphviz_exit(EXIT_FAILURE);
   }
 
-  return stack_top(stk);
+  return *strs_back(stk);
 }
 
-static void freeString(gv_stack_t *stk) {
-  while (!stack_is_empty(stk)) {
-    char *s = stack_pop(stk);
-    free(s);
-  }
-  stack_reset(stk);
+static void freeString(strs_t *stk) {
+  strs_free(stk);
 }
 
 typedef struct {
     char* gname;
-    gv_stack_t elements;
+    strs_t elements;
     int closedElementType;
     bool edgeinverted;
 } userdata_t;
 
 static Agraph_t *root;		/* root graph */
-static int Current_class;	/* Current element type */
 static Agraph_t *G;		/* Current graph */
-static Agnode_t *N;		/* Set if Current_class == TAG_NODE */
-static Agedge_t *E;		/* Set if Current_class == TAG_EDGE */
+static Agedge_t *E; // current edge
 
-static gv_stack_t Gstack;
+DEFINE_LIST(graph_stack, Agraph_t *)
+static graph_stack_t Gstack;
 
 static userdata_t genUserdata(char *dfltname) {
   userdata_t user = {0};
-  user.elements = (gv_stack_t){0};
+  user.elements = (strs_t){0};
   user.closedElementType = TAG_NONE;
   user.edgeinverted = false;
   user.gname = dfltname;
@@ -125,12 +124,12 @@ static int isAnonGraph(const char *name) {
 static void push_subg(Agraph_t * g)
 {
   // save the root if this is the first graph
-  if (stack_is_empty(&Gstack)) {
+  if (graph_stack_is_empty(&Gstack)) {
     root = g;
   }
 
   // insert the new graph
-  stack_push(&Gstack, g);
+  graph_stack_push_back(&Gstack, g);
 
   // update the top graph
   G = g;
@@ -138,17 +137,17 @@ static void push_subg(Agraph_t * g)
 
 static Agraph_t *pop_subg(void)
 {
-  if (stack_is_empty(&Gstack)) {
+  if (graph_stack_is_empty(&Gstack)) {
     fprintf(stderr, "graphml2gv: Gstack underflow in graph parser\n");
     graphviz_exit(EXIT_FAILURE);
   }
 
   // pop the top graph
-  Agraph_t *g = stack_pop(&Gstack);
+  Agraph_t *g = graph_stack_pop_back(&Gstack);
 
   // update the top graph
-  if (!stack_is_empty(&Gstack)) {
-    G = stack_top(&Gstack);
+  if (!graph_stack_is_empty(&Gstack)) {
+    G = *graph_stack_back(&Gstack);
   }
 
   return g;
@@ -156,8 +155,7 @@ static Agraph_t *pop_subg(void)
 
 static Agnode_t *bind_node(const char *name)
 {
-    N = agnode(G, (char *) name, 1);
-    return N;
+  return agnode(G, (char *)name, 1);
 }
 
 static Agedge_t *bind_edge(const char *tail, const char *head)
@@ -185,9 +183,8 @@ static int get_xml_attr(char *attrname, const char **atts)
 
 static char *defval = "";
 
-static void
-setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
-{
+static void setEdgeAttr(Agedge_t *ep, char *name, const char *value,
+                        userdata_t *ud) {
     Agsym_t *ap;
     char *attrname;
 
@@ -234,7 +231,6 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	Agdesc_t dir;
 	char buf[NAMEBUF];	/* holds % + number */
 
-	Current_class = TAG_GRAPH;
 	if (ud->closedElementType == TAG_GRAPH) {
 	    fprintf(stderr,
 		    "Warning: Node contains more than one graph.\n");
@@ -250,7 +246,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    edgeMode = atts[pos];
 	}
 
-	if (stack_is_empty(&Gstack)) {
+	if (graph_stack_is_empty(&Gstack)) {
 	    if (strcmp(edgeMode, "directed") == 0) {
 		dir = Agdirected;
 	    } else if (strcmp(edgeMode, "undirected") == 0) {
@@ -277,7 +273,6 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 	pushString(&ud->elements, id);
     } else if (strcmp(name, "node") == 0) {
-	Current_class = TAG_NODE;
 	pos = get_xml_attr("id", atts);
 	if (pos > 0) {
 	    const char *attrname;
@@ -295,7 +290,6 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	char *tname;
 	Agnode_t *t;
 
-	Current_class = TAG_EDGE;
 	pos = get_xml_attr("source", atts);
 	if (pos > 0)
 	    tail = atts[pos];
@@ -319,7 +313,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 	    pos = get_xml_attr("id", atts);
 	    if (pos > 0) {
-	        setEdgeAttr(E, GRAPHML_ID, (char *) atts[pos], ud);
+	        setEdgeAttr(E, GRAPHML_ID, atts[pos], ud);
 	    }
         }
     } else {
@@ -345,11 +339,8 @@ static void endElementHandler(void *userData, const char *name)
 	    if (node) agdelete(root, node);
 	}
 	popString(&ud->elements);
-	Current_class = TAG_GRAPH;
-	N = 0;
 	ud->closedElementType = TAG_NODE;
     } else if (strcmp(name, "edge") == 0) {
-	Current_class = TAG_GRAPH;
 	E = 0;
 	ud->closedElementType = TAG_EDGE;
 	ud->edgeinverted = false;
@@ -366,14 +357,14 @@ static Agraph_t *graphml_to_gv(char *graphname, FILE *graphmlFile, int *rv) {
     XML_SetUserData(parser, &udata);
     XML_SetElementHandler(parser, startElementHandler, endElementHandler);
 
-    Current_class = TAG_GRAPH;
     root = 0;
     do {
 	size_t len = fread(buf, 1, sizeof(buf), graphmlFile);
 	if (len == 0)
 	    break;
 	done = len < sizeof(buf);
-	if (XML_Parse(parser, buf, len, done) == XML_STATUS_ERROR) {
+	assert(len <= INT_MAX);
+	if (XML_Parse(parser, buf, (int)len, done) == XML_STATUS_ERROR) {
 	    fprintf(stderr,
 		    "%s at line %lu\n",
 		    XML_ErrorString(XML_GetErrorCode(parser)),
@@ -519,7 +510,7 @@ int main(int argc, char **argv)
 	}
     }
 
-    stack_reset(&Gstack);
+    graph_stack_free(&Gstack);
 
     agxbfree(&buf);
     graphviz_exit(rv);
