@@ -44,9 +44,11 @@
 #include <cgraph/unreachable.h>
 #include <float.h>
 #include <inttypes.h>
+#include <limits.h>
 #include <math.h>
 #include <stddef.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <stdio.h>
 
 #define DEFAULT_BORDER    1
@@ -258,19 +260,20 @@ static void doBorder(GVJ_t * job, htmldata_t * dp, boxf b)
     unsigned short sides;
 
     gvrender_set_pencolor(job, color);
-    if (dp->style & (DASHED | DOTTED)) {
+    if (dp->style.dashed || dp->style.dotted) {
 	sptr[0] = sptr[1] = NULL;
-	if (dp->style & DASHED)
+	if (dp->style.dashed)
 	    sptr[0] = "dashed";
-	else if (dp->style & DOTTED)
+	else if (dp->style.dotted)
 	    sptr[0] = "dotted";
 	gvrender_set_style(job, sptr);
     } else
 	gvrender_set_style(job, job->gvc->defaultlinestyle);
     gvrender_set_penwidth(job, dp->border);
 
-    if (dp->style & ROUNDED)
-	round_corners(job, mkPts(AF, b, dp->border), 4, ROUNDED, 0);
+    if (dp->style.rounded)
+	round_corners(job, mkPts(AF, b, dp->border), 4,
+	              (graphviz_polygon_style_t){.rounded = true}, 0);
     else if ((sides = (dp->flags & BORDER_MASK))) {
 	mkPts (AF+1, b, dp->border);  /* AF[1-4] has LL=SW,SE,UR=NE,NW */
 	switch (sides) {
@@ -326,6 +329,8 @@ static void doBorder(GVJ_t * job, htmldata_t * dp, boxf b)
 	    gvrender_polyline(job, AF, 2);
 	    gvrender_polyline(job, AF+2, 2);
 	    break;
+	default:
+	    break;
 	}
     } else {
 	if (dp->border > 1) {
@@ -343,18 +348,17 @@ static void doBorder(GVJ_t * job, htmldata_t * dp, boxf b)
  * Set up fill values from given color; make pen transparent.
  * Return type of fill required.
  */
-static int
-setFill(GVJ_t * job, char *color, int angle, int style, char *clrs[2])
-{
+static int setFill(GVJ_t *job, char *color, int angle, htmlstyle_t style,
+                   char *clrs[2]) {
     int filled;
-    float frac;
+    double frac;
     if (findStopColor(color, clrs, &frac)) {
 	gvrender_set_fillcolor(job, clrs[0]);
 	if (clrs[1])
 	    gvrender_set_gradient_vals(job, clrs[1], angle, frac);
 	else
 	    gvrender_set_gradient_vals(job, DEFAULT_COLOR, angle, frac);
-	if (style & RADIAL)
+	if (style.radial)
 	    filled = RGRADIENT;
 	else
 	    filled = GRADIENT;
@@ -544,7 +548,7 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
     else
 	anchor = 0;
 
-    if (!(tbl->data.style & INVISIBLE)) {
+    if (!tbl->data.style.invisible) {
 
 	/* Fill first */
 	if (tbl->data.bgcolor) {
@@ -552,9 +556,9 @@ static void emit_html_tbl(GVJ_t * job, htmltbl_t * tbl, htmlenv_t * env)
 	    int filled =
 		setFill(job, tbl->data.bgcolor, tbl->data.gradientangle,
 			tbl->data.style, clrs);
-	    if (tbl->data.style & ROUNDED) {
+	    if (tbl->data.style.rounded) {
 		round_corners(job, mkPts(AF, pts, tbl->data.border), 4,
-			      ROUNDED, filled);
+		              (graphviz_polygon_style_t){.rounded = true}, filled);
 	    } else
 		gvrender_box(job, pts, filled);
 	    free(clrs[0]);
@@ -644,15 +648,15 @@ static void emit_html_cell(GVJ_t * job, htmlcell_t * cp, htmlenv_t * env)
     else
 	inAnchor = 0;
 
-    if (!(cp->data.style & INVISIBLE)) {
+    if (!cp->data.style.invisible) {
 	if (cp->data.bgcolor) {
 	    char *clrs[2];
 	    int filled =
 		setFill(job, cp->data.bgcolor, cp->data.gradientangle,
 			cp->data.style, clrs);
-	    if (cp->data.style & ROUNDED) {
+	    if (cp->data.style.rounded) {
 		round_corners(job, mkPts(AF, pts, cp->data.border), 4,
-			      ROUNDED, filled);
+			      (graphviz_polygon_style_t){.rounded = true}, filled);
 	    } else
 		gvrender_box(job, pts, filled);
 	    free(clrs[0]);
@@ -706,6 +710,8 @@ static void allocObj(GVJ_t * job)
     case EDGE_OBJTYPE:
 	obj->u.e = parent->u.e;
 	break;
+    default:
+	UNREACHABLE();
     }
     obj->url = parent->url;
     obj->tooltip = parent->tooltip;
@@ -1164,8 +1170,7 @@ size_html_cell(graph_t * g, htmlcell_t * cp, htmltbl_t * parent,
     return rv;
 }
 
-static int findCol(PointSet * ps, int row, int col, htmlcell_t * cellp)
-{
+static uint16_t findCol(PointSet *ps, int row, int col, htmlcell_t *cellp) {
     int notFound = 1;
     int lastc;
     int i, j, c;
@@ -1187,7 +1192,8 @@ static int findCol(PointSet * ps, int row, int col, htmlcell_t * cellp)
 	    addPS(ps, j, i);
 	}
     }
-    return col;
+    assert(col >= 0 && col <= UINT16_MAX);
+    return (uint16_t)col;
 }
 
 /* processTbl:
@@ -1347,18 +1353,19 @@ static void checkChain(graph_t * g)
  * Check for edge in g. If it exists, set its minlen to max of sz and
  * current minlen. Else, create it and set minlen to sz.
  */
-static void
-checkEdge (graph_t* g, node_t* t, node_t* h, int sz)
-{
+static void checkEdge(graph_t *g, node_t *t, node_t *h, double sz) {
     edge_t* e;
 
+    const int sz_as_int = sz > INT_MAX ? INT_MAX :
+                          sz < INT_MIN ? INT_MIN : (int)sz;
+
     e = agfindedge (g, t, h);
     if (e)
-	ED_minlen(e) = MAX(ED_minlen(e), sz);
+	ED_minlen(e) = MAX(ED_minlen(e), sz_as_int);
     else {
 	e = agedge(g, t, h, NULL, 1);
 	agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);
-	ED_minlen(e) = sz;
+	ED_minlen(e) = sz_as_int;
 	elist_append(e, ND_out(t));
 	elist_append(e, ND_in(h));
     }
@@ -1493,7 +1500,7 @@ static void sizeArray(htmltbl_t * tbl)
     closeGraphs(rowg, colg);
 }
 
-static void pos_html_tbl(htmltbl_t *, boxf, int);	/* forward declaration */
+static void pos_html_tbl(htmltbl_t *, boxf, unsigned char);
 
 /* pos_html_img:
  * Place image in cell
@@ -1518,8 +1525,7 @@ static void pos_html_txt(htmltxt_t * ftxt, char c)
 
 /* pos_html_cell:
  */
-static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
-{
+static void pos_html_cell(htmlcell_t *cp, boxf pos, unsigned char sides) {
     double delx, dely;
     pointf oldsz;
     boxf cbox;
@@ -1586,6 +1592,8 @@ static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
 	    case HALIGN_RIGHT:
 		cbox.LL.x += delx;
 		break;
+	    default:
+		break;
 	    }
 	}
 
@@ -1598,6 +1606,8 @@ static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
 	    case VALIGN_TOP:
 		cbox.LL.y += dely;
 		break;
+	    default:
+		break;
 	    }
 	}
 	pos_html_img(cp->child.u.img, cbox);
@@ -1665,8 +1675,7 @@ static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
  * attribute indicating which external sides of the node
  * are accessible to the table.
  */
-static void pos_html_tbl(htmltbl_t * tbl, boxf pos, int sides)
-{
+static void pos_html_tbl(htmltbl_t *tbl, boxf pos, unsigned char sides) {
     int plus;
     htmlcell_t **cells = tbl->u.n.cells;
     htmlcell_t *cp;
@@ -1738,7 +1747,7 @@ static void pos_html_tbl(htmltbl_t * tbl, boxf pos, int sides)
     }
 
     while ((cp = *cells++)) {
-	int mask = 0;
+	unsigned char mask = 0;
 	if (sides) {
 	    if (cp->col == 0)
 		mask |= LEFT;
