@@ -20,13 +20,13 @@
 #include <cgraph/overflow.h>
 #include <cgraph/prisize_t.h>
 #include <cgraph/queue.h>
-#include <cgraph/streq.h>
 #include <common/render.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdint.h>
 #include <stdio.h>
+#include <util/streq.h>
 
 static void dfs_cutval(node_t * v, edge_t * par);
 static int dfs_range_init(node_t * v, edge_t * par, int low);
@@ -353,7 +353,7 @@ static subtree_t *find_tight_subtree(Agnode_t *v)
 
 typedef struct STheap_s {
         subtree_t       **elt;
-        int             size;
+        size_t          size;
 } STheap_t;
 
 static subtree_t *STsetFind(Agnode_t *n0)
@@ -1150,12 +1150,12 @@ static int dfs_range(node_t * v, edge_t * par, int low)
 #ifdef DEBUG
 void tchk(void)
 {
-    int i, n_cnt, e_cnt;
+    int i;
     node_t *n;
     edge_t *e;
 
-    n_cnt = 0;
-    e_cnt = 0;
+    size_t n_cnt = 0;
+    size_t e_cnt = 0;
     for (n = agfstnode(G); n; n = agnxtnode(G, n)) {
 	n_cnt++;
 	for (i = 0; (e = ND_tree_out(n).list[i]); i++) {
