@@ -24,11 +24,12 @@
 #include <gvc/gvc.h>
 #include <cgraph/startswith.h>
 #include <cgraph/strcasecmp.h>
-#include <cgraph/streq.h>
+#include <cgraph/strview.h>
 #include <stddef.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <unistd.h>
+#include <util/streq.h>
 
 int late_int(void *obj, attrsym_t *attr, int defaultValue, int minimum) {
     if (attr == NULL)
@@ -510,15 +511,12 @@ void common_init_edge(edge_t *e) {
 
     fi.fontname = NULL;
     lfi.fontname = NULL;
-    if (E_label && (str = agxget(e, E_label))) {
+    if (E_label && (str = agxget(e, E_label)) && str[0]) {
 	initFontEdgeAttr(e, &fi);
-	const int kind = !streq(str, "") && aghtmlstr(str) ? LT_HTML : LT_NONE;
-	ED_label(e) = make_label(e, str, kind,
+	ED_label(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 				fi.fontsize, fi.fontname, fi.fontcolor);
-	if (!streq(str, "")) {
-	    GD_has_labels(sg) |= EDGE_LABEL;
-	    ED_label_ontop(e) = mapbool(late_string(e, E_label_float, "false"));
-	}
+	GD_has_labels(sg) |= EDGE_LABEL;
+	ED_label_ontop(e) = mapbool(late_string(e, E_label_float, "false"));
     }
 
     if (E_xlabel && (str = agxget(e, E_xlabel)) && str[0]) {
@@ -755,11 +753,9 @@ typedef struct {
     node_t *h;
 } item;
 
-static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
-{
-    (void)d;
-    (void)disc;
-
+static int cmpItem(void *pp1, void *pp2) {
+    const void **p1 = pp1;
+    const void **p2 = pp2;
     if (p1[0] < p2[0])
 	return -1;
     if (p1[0] > p2[0])
@@ -771,7 +767,8 @@ static int cmpItem(Dt_t * d, void *p1[], void *p2[], Dtdisc_t * disc)
     return 0;
 }
 
-static void *newItem(item *objp, Dtdisc_t *disc) {
+static void *newItem(void *p, Dtdisc_t *disc) {
+    item *objp = p;
     item *newp = gv_alloc(sizeof(item));
 
     (void)disc;
@@ -783,18 +780,13 @@ static void *newItem(item *objp, Dtdisc_t *disc) {
     return newp;
 }
 
-static void freeItem(item *obj, Dtdisc_t *disc) {
-    (void)disc;
-    free(obj);
-}
-
 static Dtdisc_t mapDisc = {
     .key = offsetof(item, p),
     .size = sizeof(2 * sizeof(void *)),
     .link = offsetof(item, link),
-    .makef = (Dtmake_f)newItem,
-    .freef = (Dtfree_f)freeItem,
-    .comparf = (Dtcompar_f)cmpItem,
+    .makef = newItem,
+    .freef = free,
+    .comparf = cmpItem,
 };
 
 /// Make a copy of e in e's graph but using ct and ch as nodes
@@ -836,6 +828,13 @@ static item *mapEdge(Dt_t * map, edge_t * e)
     return dtmatch(map, &key);
 }
 
+static graph_t *mapc(Dt_t *cmap, node_t *n) {
+  if (startswith(agnameof(n), "cluster")) {
+    return findCluster(cmap, agnameof(n));
+  }
+  return NULL;
+}
+
 /** If endpoint names a cluster, mark for temporary deletion and create
  * special node and insert into cluster. Then clone the edge. Real edge
  * will be deleted when we delete the original node.
@@ -851,13 +850,9 @@ static item *mapEdge(Dt_t * map, edge_t * e)
  *
  * Return 1 if cluster edge is created.
  */
-#define MAPC(n) (startswith(agnameof(n), "cluster") ? findCluster(cmap, agnameof(n)) : NULL)
-
 static int
 checkCompound(edge_t * e, graph_t * clg, agxbuf * xb, Dt_t * map, Dt_t* cmap)
 {
-    graph_t *tg;
-    graph_t *hg;
     node_t *cn;
     node_t *cn1;
     node_t *t = agtail(e);
@@ -866,8 +861,8 @@ checkCompound(edge_t * e, graph_t * clg, agxbuf * xb, Dt_t * map, Dt_t* cmap)
     item *ip;
 
     if (IS_CLUST_NODE(h)) return 0;
-    tg = MAPC(t);
-    hg = MAPC(h);
+    graph_t *const tg = mapc(cmap, t);
+    graph_t *const hg = mapc(cmap, h);
     if (!tg && !hg)
 	return 0;
     if (tg == hg) {
@@ -1082,32 +1077,28 @@ attrsym_t *safe_dcl(graph_t *g, int obj_kind, char *name, char *defaultValue) {
 }
 
 static int comp_entities(const void *e1, const void *e2) {
-  return strcmp(e1, ((const struct entities_s *)e2)->name);
+  const strview_t *key = e1;
+  const struct entities_s *candidate = e2;
+  return strview_cmp(*key, strview(candidate->name, '\0'));
 }
 
-#define MAXENTLEN 8
-
 /** Scan non-numeric entity, convert to &#...; form and store in xbuf.
  * t points to first char after '&'. Return after final semicolon.
  * If unknown, we return t and let libexpat flag the error.
  *     */
 char* scanEntity (char* t, agxbuf* xb)
 {
-    char*  endp = strchr (t, ';');
+    const strview_t key = strview(t, ';');
     struct entities_s *res;
-    size_t len;
-    char   buf[MAXENTLEN+1];
 
     agxbputc(xb, '&');
-    if (!endp) return t;
-    if ((len = (size_t)(endp - t)) > MAXENTLEN || len < 2) return t;
-    strncpy (buf, t, len);
-    buf[len] = '\0';
-    res = bsearch(buf, entities, NR_OF_ENTITIES,
+    if (key.data[key.size] == '\0') return t;
+    if (key.size > ENTITY_NAME_LENGTH_MAX || key.size < 2) return t;
+    res = bsearch(&key, entities, NR_OF_ENTITIES,
         sizeof(entities[0]), comp_entities);
     if (!res) return t;
     agxbprint(xb, "#%d;", res->value);
-    return endp + 1;
+    return t + key.size + 1;
 }
 
 /** Check for an HTML entity for a special character.
@@ -1119,9 +1110,7 @@ char* scanEntity (char* t, agxbuf* xb)
 static int
 htmlEntity (char** s)
 {
-    char *p;
     struct entities_s *res;
-    char entity_name_buf[ENTITY_NAME_LENGTH_MAX+1];
     unsigned char* str = *(unsigned char**)s;
     unsigned int byte;
     int i, n = 0;
@@ -1160,13 +1149,12 @@ htmlEntity (char** s)
 	}
     }
     else {
-	p = entity_name_buf;
+	strview_t key = {.data = (char *)str};
 	for (i = 0; i <  ENTITY_NAME_LENGTH_MAX; i++) {
 	    byte = *(str + i);
 	    if (byte == '\0') break;
 	    if (byte == ';') {
-		*p++ = '\0';
-		res = bsearch(entity_name_buf, entities, NR_OF_ENTITIES,
+		res = bsearch(&key, entities, NR_OF_ENTITIES,
 		    sizeof(entities[0]), comp_entities);
 		if (res) {
 		    n = res->value;
@@ -1174,7 +1162,7 @@ htmlEntity (char** s)
 		}
 		break;
 	    }
-	    *p++ = (char)byte;
+	    ++key.size;
 	}
     }
     *s = (char*)str;
@@ -1588,16 +1576,11 @@ typedef struct {
     Agraph_t* clp;
 } clust_t;
 
-static void free_clust(clust_t *clp, Dtdisc_t *disc) {
-    (void)disc;
-    free(clp);
-}
-
 static Dtdisc_t strDisc = {
     .key = offsetof(clust_t, name),
     .size = -1,
     .link = offsetof(clust_t, link),
-    .freef = (Dtfree_f)free_clust,
+    .freef = free,
 };
 
 static void fillMap (Agraph_t* g, Dt_t* map)
