@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -24,7 +24,7 @@
  */
 
 #include	<cgraph/alloc.h>
-#include	<cgraph/clamp.h>
+#include	<cgraph/gv_math.h>
 #include	<dotgen/dot.h>
 #include	<limits.h>
 #include	<stdbool.h>
@@ -447,7 +447,7 @@ static void dot1_rank(graph_t *g)
 }
 
 void dot_rank(graph_t *g) {
-    if (agget (g, "newrank")) {
+    if (mapbool(agget(g, "newrank"))) {
 	GD_flags(g) |= NEW_RANK;
 	dot2_rank(g);
     }
@@ -494,7 +494,7 @@ static bool is_empty(graph_t *g) {
 static bool is_a_strong_cluster(graph_t * g)
 {
     char *str = agget(g, "compact");
-    return mapBool(str, false);
+    return mapbool(str);
 }
 
 static int rankset_kind(graph_t * g)
@@ -617,7 +617,7 @@ static void compile_samerank(graph_t * ug, graph_t * parent_clust)
     case NORANK:
 	break;
     default:			/* unrecognized - warn and do nothing */
-	agerr(AGWARN, "%s has unrecognized rank=%s", agnameof(ug),
+	agwarningf("%s has unrecognized rank=%s", agnameof(ug),
 	      agget(ug, "rank"));
     }
 
@@ -703,7 +703,7 @@ static void strong(graph_t * g, node_t * t, node_t * h, edge_t * orig)
 	(e = agfindedge(g, h, t)) || (e = agedge(g, t, h, 0, 1)))
 	merge(e, ED_minlen(orig), ED_weight(orig));
     else
-	agerr(AGERR, "ranking: failure to create strong constraint edge between nodes %s and %s\n", 
+	agerrorf("ranking: failure to create strong constraint edge between nodes %s and %s\n", 
 	    agnameof(t), agnameof(h));
 }
 
