@@ -8,6 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -19,9 +21,6 @@ extern "C" {
  * expression library private definitions
  */
 
-#ifndef _EXLIB_H
-#define _EXLIB_H
-
 #include <ast/ast.h>
 #include <cgraph/agxbuf.h>
 #include <sfio/sfio.h>
@@ -114,7 +113,7 @@ typedef struct Print_s			/* compiled printf arg node	*/
 	int		formals;	/* parsing formal args		*/ \
 	int		linewrap;	/* linep wrapped around line[]	*/ \
 	long long loopcount; /* break|continue|return count	*/ \
-	int		loopop;		/* break|continue|return op	*/ \
+	long loopop; /* break|continue|return op	*/ \
 	int		nesting;	/* exstatement() nesting	*/
 
 #include <expr/expr.h>
@@ -158,8 +157,6 @@ typedef struct Exstate_s		/* ex global state		*/
 	Exnode_t*	procedure;	/* current procedure		*/
 	Exref_t*	refs;		/* . reference list		*/
 	int		assigned;	/* declaration assignment	*/
-	int		instatic;	/* static declaration		*/
-	int		statics;	/* static used			*/
 	Switch_t*	swstate;	/* switch parse state		*/
 	char		nullstring[1];	/* ""				*/
 } Exstate_t;
@@ -170,8 +167,6 @@ extern Exstate_t	expr;
 
 extern int		ex_parse(void);	/* yacc should do this		*/
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
