@@ -26,7 +26,6 @@
 #include <neatogen/info.h>
 #include <neatogen/edges.h>
 #include <neatogen/site.h>
-#include <neatogen/heap.h>
 #include <neatogen/hedges.h>
 #include <neatogen/digcola.h>
 #if ((defined(HAVE_GTS) || defined(HAVE_TRIANGLE)) && defined(SFDP))
@@ -42,30 +41,26 @@
 
 #define SEPFACT         0.8 // default esep/sep
 
-static double margin = 0.05;	/* Create initial bounding box by adding
-				 * margin * dimension around box enclosing
-				 * nodes.
-				 */
 static const double incr = 0.05;	/* Increase bounding box by adding
 				 * incr * dimension around box.
 				 */
-static bool doAll = false; // Move all nodes, regardless of overlap
-static Site **sites;		/* Array of pointers to sites; used in qsort */
-static Site **endSite;		/* Sentinel on sites array */
-static Point nw, ne, sw, se;	/* Corners of clipping window */
 
-static Site **nextSite;
+typedef struct {
+  Site **sites; ///< array of pointers to sites; used in qsort
+  Site **endSite; ///< sentinel on sites array
+  Point nw, ne, sw, se; ///< corners of clipping window
+  Site **nextSite;
+} state_t;
 
-static void setBoundBox(Point * ll, Point * ur)
-{
+static void setBoundBox(state_t *st, Point *ll, Point *ur) {
     pxmin = ll->x;
     pxmax = ur->x;
     pymin = ll->y;
     pymax = ur->y;
-    nw.x = sw.x = pxmin;
-    ne.x = se.x = pxmax;
-    nw.y = ne.y = pymax;
-    sw.y = se.y = pymin;
+    st->nw.x = st->sw.x = pxmin;
+    st->ne.x = st->se.x = pxmax;
+    st->nw.y = st->ne.y = pymax;
+    st->sw.y = st->se.y = pymin;
 }
 
 /// Free node resources.
@@ -75,7 +70,9 @@ static void freeNodes(void)
 	breakPoly(&nodeInfo[i].poly);
     }
     polyFree();
-    infoinit();			/* Free vertices */
+    if (nodeInfo != NULL) {
+	free(nodeInfo->verts); // Free vertices
+    }
     free(nodeInfo);
 }
 
@@ -86,8 +83,7 @@ static void freeNodes(void)
  *   graph extremes.
  *   In the first two cases, check that graph fits in bounding box.
  */
-static void chkBoundBox(Agraph_t * graph)
-{
+static void chkBoundBox(state_t *st, Agraph_t *graph) {
     Point ll, ur;
 
     double x_min = DBL_MAX;
@@ -106,10 +102,10 @@ static void chkBoundBox(Agraph_t * graph)
 	y_max = fmax(y_max, pp->corner.y + y);
     }
 
+    // create initial bounding box by adding margin × dimension around box
+    // enclosing nodes
     char *marg = agget(graph, "voro_margin");
-    if (marg && *marg != '\0') {
-	margin = atof(marg);
-    }
+    const double margin = (marg && *marg != '\0') ? atof(marg) : 0.05;
     double ydelta = margin * (y_max - y_min);
     double xdelta = margin * (x_max - x_min);
     ll.x = x_min - xdelta;
@@ -117,7 +113,7 @@ static void chkBoundBox(Agraph_t * graph)
     ur.x = x_max + xdelta;
     ur.y = y_max + ydelta;
 
-    setBoundBox(&ll, &ur);
+    setBoundBox(st, &ll, &ur);
 }
 
  /// For each node in the graph, create a Info data structure 
@@ -158,6 +154,7 @@ static int makeInfo(Agraph_t * graph)
 	ip->site.refcnt = 1;
 	ip->node = node;
 	ip->verts = NULL;
+	ip->n_verts = 0;
 	node = agnxtnode(graph, node);
     }
     return 0;
@@ -180,64 +177,60 @@ static int scomp(const void *S1, const void *S2)
 }
 
  /// Fill array of pointer to sites and sort the sites using scomp
-static void sortSites(void)
-{
-    if (sites == 0) {
-	sites = gv_calloc(nsites, sizeof(Site*));
-	endSite = sites + nsites;
+static void sortSites(state_t *st) {
+    if (st->sites == NULL) {
+	st->sites = gv_calloc(nsites, sizeof(Site*));
+	st->endSite = st->sites + nsites;
     }
 
-    infoinit();
     for (size_t i = 0; i < nsites; i++) {
 	Info_t *ip = &nodeInfo[i];
-	sites[i] = &ip->site;
+	st->sites[i] = &ip->site;
 	ip->verts = NULL;
+	ip->n_verts = 0;
 	ip->site.refcnt = 1;
     }
 
-    qsort(sites, nsites, sizeof(Site *), scomp);
+    qsort(st->sites, nsites, sizeof(Site *), scomp);
 
     /* Reset site index for nextOne */
-    nextSite = sites;
+    st->nextSite = st->sites;
 
 }
 
-static void geomUpdate(int doSort)
-{
+static void geomUpdate(state_t *st, int doSort) {
     if (doSort)
-	sortSites();
+	sortSites(st);
 
     /* compute ranges */
     xmin = DBL_MAX;
     xmax = -DBL_MAX;
     assert(nsites > 0);
     for (size_t i = 0; i < nsites; ++i) {
-	xmin = fmin(xmin, sites[i]->coord.x);
-	xmax = fmax(xmax, sites[i]->coord.x);
+	xmin = fmin(xmin, st->sites[i]->coord.x);
+	xmax = fmax(xmax, st->sites[i]->coord.x);
     }
-    ymin = sites[0]->coord.y;
-    ymax = sites[nsites - 1]->coord.y;
+    ymin = st->sites[0]->coord.y;
+    ymax = st->sites[nsites - 1]->coord.y;
 
-    deltay = ymax - ymin;
     deltax = xmax - xmin;
 }
 
-static Site *nextOne(void)
-{
-    if (nextSite < endSite) {
-	return *nextSite++;
+static Site *nextOne(void *state) {
+    state_t *st = state;
+    if (st->nextSite < st->endSite) {
+	return *st->nextSite++;
     } else
 	return NULL;
 }
 
 /// Check for nodes with identical positions and tweak the positions.
-static void rmEquality(void)
-{
-    sortSites();
+static void rmEquality(state_t *st) {
+    sortSites(st);
 
-    for (Site **ip = sites; ip < endSite; ) {
+    for (Site **ip = st->sites; ip < st->endSite; ) {
 	Site **jp = ip + 1;
-	if (jp >= endSite ||
+	if (jp >= st->endSite ||
 	    (*jp)->coord.x != (*ip)->coord.x ||
 	    (*jp)->coord.y != (*ip)->coord.y) {
 	    ip = jp;
@@ -247,7 +240,7 @@ static void rmEquality(void)
 	/* Find first node kp with position different from ip */
 	int cnt = 2;
 	Site **kp = jp + 1;
-	while (kp < endSite &&
+	while (kp < st->endSite &&
 	       (*kp)->coord.x == (*ip)->coord.x &&
 	       (*kp)->coord.y == (*ip)->coord.y) {
 	    cnt++;
@@ -256,7 +249,7 @@ static void rmEquality(void)
 	}
 
 	/* If next node exists and is on the same line */
-	if (kp < endSite && (*kp)->coord.y == (*ip)->coord.y) {
+	if (kp < st->endSite && (*kp)->coord.y == (*ip)->coord.y) {
 	    const double xdel = ((*kp)->coord.x - (*ip)->coord.x) / cnt;
 	    int i = 1;
 	    for (jp = ip + 1; jp < kp; jp++) {
@@ -278,12 +271,11 @@ static void rmEquality(void)
 }
 
 /// Count number of node-node overlaps at iteration iter.
-static int countOverlap(int iter)
-{
-    int count = 0;
+static unsigned countOverlap(unsigned iter) {
+    unsigned count = 0;
 
     for (size_t i = 0; i < nsites; i++)
-	nodeInfo[i].overlaps = 0;
+	nodeInfo[i].overlaps = false;
 
     for (size_t i = 0; i < nsites - 1; i++) {
 	Info_t *ip = &nodeInfo[i];
@@ -291,19 +283,18 @@ static int countOverlap(int iter)
 	    Info_t *jp = &nodeInfo[j];
 	    if (polyOverlap(ip->site.coord, &ip->poly, jp->site.coord, &jp->poly)) {
 		count++;
-		ip->overlaps = 1;
-		jp->overlaps = 1;
+		ip->overlaps = true;
+		jp->overlaps = true;
 	    }
 	}
     }
 
     if (Verbose > 1)
-	fprintf(stderr, "overlap [%d] : %d\n", iter, count);
+	fprintf(stderr, "overlap [%u] : %u\n", iter, count);
     return count;
 }
 
-static void increaseBoundBox(void)
-{
+static void increaseBoundBox(state_t *st) {
     Point ur = {.x = pxmax, .y = pymax};
     Point ll = {.x = pxmin, .y = pymin};
 
@@ -315,7 +306,7 @@ static void increaseBoundBox(void)
     ll.x -= xdelta;
     ll.y -= ydelta;
 
-    setBoundBox(&ll, &ur);
+    setBoundBox(st, &ll, &ur);
 }
 
 /// Area of triangle whose vertices are a,b,c
@@ -338,23 +329,21 @@ static void centroidOf(Point a, Point b, Point c, double *x, double *y)
  */
 static void newpos(Info_t * ip)
 {
-    PtItem *anchor = ip->verts;
+    const Point anchor = ip->verts[0];
     double totalArea = 0.0;
     double cx = 0.0;
     double cy = 0.0;
     double x;
     double y;
 
-    PtItem *p = anchor->next;
-    PtItem *q = p->next;
-    while (q != NULL) {
-	const double area = areaOf(anchor->p, p->p, q->p);
-	centroidOf(anchor->p, p->p, q->p, &x, &y);
+    for (size_t i = 1; i + 1 < ip->n_verts; ++i) {
+	const Point p = ip->verts[i];
+	const Point q = ip->verts[i + 1];
+	const double area = areaOf(anchor, p, q);
+	centroidOf(anchor, p, q, &x, &y);
 	cx += area * x;
 	cy += area * y;
 	totalArea += area;
-	p = q;
-	q = q->next;
     }
 
     ip->site.coord.x = cx / totalArea;
@@ -364,46 +353,45 @@ static void newpos(Info_t * ip)
  /* Add corners of clipping window to appropriate sites.
   * A site gets a corner if it is the closest site to that corner.
   */
-static void addCorners(void)
-{
+static void addCorners(const state_t *st) {
     Info_t *ip = nodeInfo;
     Info_t *sws = ip;
     Info_t *nws = ip;
     Info_t *ses = ip;
     Info_t *nes = ip;
-    double swd = dist_2(&ip->site.coord, &sw);
-    double nwd = dist_2(&ip->site.coord, &nw);
-    double sed = dist_2(&ip->site.coord, &se);
-    double ned = dist_2(&ip->site.coord, &ne);
+    double swd = dist_2(ip->site.coord, st->sw);
+    double nwd = dist_2(ip->site.coord, st->nw);
+    double sed = dist_2(ip->site.coord, st->se);
+    double ned = dist_2(ip->site.coord, st->ne);
 
     for (size_t i = 1; i < nsites; i++) {
 	ip = &nodeInfo[i];
-	double d = dist_2(&ip->site.coord, &sw);
+	double d = dist_2(ip->site.coord, st->sw);
 	if (d < swd) {
 	    swd = d;
 	    sws = ip;
 	}
-	d = dist_2(&ip->site.coord, &se);
+	d = dist_2(ip->site.coord, st->se);
 	if (d < sed) {
 	    sed = d;
 	    ses = ip;
 	}
-	d = dist_2(&ip->site.coord, &nw);
+	d = dist_2(ip->site.coord, st->nw);
 	if (d < nwd) {
 	    nwd = d;
 	    nws = ip;
 	}
-	d = dist_2(&ip->site.coord, &ne);
+	d = dist_2(ip->site.coord, st->ne);
 	if (d < ned) {
 	    ned = d;
 	    nes = ip;
 	}
     }
 
-    addVertex(&sws->site, sw.x, sw.y);
-    addVertex(&ses->site, se.x, se.y);
-    addVertex(&nws->site, nw.x, nw.y);
-    addVertex(&nes->site, ne.x, ne.y);
+    addVertex(&sws->site, st->sw.x, st->sw.y);
+    addVertex(&ses->site, st->se.x, st->se.y);
+    addVertex(&nws->site, st->nw.x, st->nw.y);
+    addVertex(&nes->site, st->ne.x, st->ne.y);
 }
 
  /* Calculate the new position of a site as the centroid
@@ -412,10 +400,12 @@ static void addCorners(void)
   * window.
   * We first add the corner of the clipping windows to the
   * vertex lists of the appropriate sites.
+  *
+  * @param st Algorithm state
+  * @param doAll Move all nodes, regardless of overlap
   */
-static void newPos(void)
-{
-    addCorners();
+static void newPos(const state_t *st, bool doAll) {
+    addCorners(st);
     for (size_t i = 0; i < nsites; i++) {
 	Info_t *ip = &nodeInfo[i];
 	if (doAll || ip->overlaps)
@@ -424,38 +414,36 @@ static void newPos(void)
 }
 
 /* Cleanup voronoi memory.
- * Note that PQcleanup and ELcleanup rely on the number
+ * Note that ELcleanup relies on the number
  * of sites, so should at least be reset every time we use vAdjust.
  * This could be optimized, over multiple components or
  * even multiple graphs, but probably not worth it.
  */
 static void cleanup(void)
 {
-    PQcleanup();
     ELcleanup();
     siteinit();			/* free memory */
     edgeinit();			/* free memory */
 }
 
-static int vAdjust(void)
-{
-    int iterCnt = 0;
-    int badLevel = 0;
-    int increaseCnt = 0;
+static int vAdjust(state_t *st) {
+    unsigned iterCnt = 0;
+    unsigned badLevel = 0;
+    unsigned increaseCnt = 0;
 
-    int overlapCnt = countOverlap(iterCnt);
+    unsigned overlapCnt = countOverlap(iterCnt);
 
     if (overlapCnt == 0)
 	return 0;
 
-    rmEquality();
-    geomUpdate(0);
-    voronoi(nextOne);
-    while (1) {
-	newPos();
+    rmEquality(st);
+    geomUpdate(st, 0);
+    voronoi(nextOne, st);
+    for (bool doAll = false;;) {
+	newPos(st, doAll);
 	iterCnt++;
 
-	const int cnt = countOverlap(iterCnt);
+	const unsigned cnt = countOverlap(iterCnt);
 	if (cnt == 0)
 	    break;
 	if (cnt >= overlapCnt)
@@ -471,25 +459,24 @@ static int vAdjust(void)
 	default:
 	    doAll = true;
 	    increaseCnt++;
-	    increaseBoundBox();
+	    increaseBoundBox(st);
 	    break;
 	}
 
-	geomUpdate(1);
-	voronoi(nextOne);
+	geomUpdate(st, 1);
+	voronoi(nextOne, st);
     }
 
     if (Verbose) {
-	fprintf(stderr, "Number of iterations = %d\n", iterCnt);
-	fprintf(stderr, "Number of increases = %d\n", increaseCnt);
+	fprintf(stderr, "Number of iterations = %u\n", iterCnt);
+	fprintf(stderr, "Number of increases = %u\n", increaseCnt);
     }
 
     cleanup();
     return 1;
 }
 
-static double rePos(void)
-{
+static void rePos(void) {
     double f = 1.0 + incr;
 
     for (size_t i = 0; i < nsites; i++) {
@@ -497,30 +484,28 @@ static double rePos(void)
 	ip->site.coord.x *= f;
 	ip->site.coord.y *= f;
     }
-    return f;
 }
 
-static int sAdjust(void)
-{
-    int iterCnt = 0;
+static int sAdjust(state_t *st) {
+    unsigned iterCnt = 0;
 
-    int overlapCnt = countOverlap(iterCnt);
+    const unsigned overlapCnt = countOverlap(iterCnt);
 
     if (overlapCnt == 0)
 	return 0;
 
-    rmEquality();
+    rmEquality(st);
     while (1) {
 	rePos();
 	iterCnt++;
 
-	const int cnt = countOverlap(iterCnt);
+	const unsigned cnt = countOverlap(iterCnt);
 	if (cnt == 0)
 	    break;
     }
 
     if (Verbose) {
-	fprintf(stderr, "Number of iterations = %d\n", iterCnt);
+	fprintf(stderr, "Number of iterations = %u\n", iterCnt);
     }
 
     return 1;
@@ -798,47 +783,41 @@ int normalize(graph_t * g)
 typedef struct {
     adjust_mode mode;
     char *attrib;
-    int len;
     char *print;
 } lookup_t;
 
-#define STRLEN(s) ((sizeof(s)-1)/sizeof(char))
-#define ITEM(i,s,v) {i, s, STRLEN(s), v}
-
 /* Translation table from overlap values to algorithms.
  * adjustMode[0] corresponds to overlap=true
  * adjustMode[1] corresponds to overlap=false
  */
 static const lookup_t adjustMode[] = {
-    ITEM(AM_NONE, "", "none"),
+    {AM_NONE, "", "none"},
 #if ((defined(HAVE_GTS) || defined(HAVE_TRIANGLE)) && defined(SFDP))
-    ITEM(AM_PRISM, "prism", "prism"),
+    {AM_PRISM, "prism", "prism"},
 #endif
-    ITEM(AM_VOR, "voronoi", "Voronoi"),
-    ITEM(AM_NSCALE, "scale", "scaling"),
-    ITEM(AM_COMPRESS, "compress", "compress"),
-    ITEM(AM_VPSC, "vpsc", "vpsc"),
-    ITEM(AM_IPSEP, "ipsep", "ipsep"),
-    ITEM(AM_SCALE, "oscale", "old scaling"),
-    ITEM(AM_SCALEXY, "scalexy", "x and y scaling"),
-    ITEM(AM_ORTHO, "ortho", "orthogonal constraints"),
-    ITEM(AM_ORTHO_YX, "ortho_yx", "orthogonal constraints"),
-    ITEM(AM_ORTHOXY, "orthoxy", "xy orthogonal constraints"),
-    ITEM(AM_ORTHOYX, "orthoyx", "yx orthogonal constraints"),
-    ITEM(AM_PORTHO, "portho", "pseudo-orthogonal constraints"),
-    ITEM(AM_PORTHO_YX, "portho_yx", "pseudo-orthogonal constraints"),
-    ITEM(AM_PORTHOXY, "porthoxy", "xy pseudo-orthogonal constraints"),
-    ITEM(AM_PORTHOYX, "porthoyx", "yx pseudo-orthogonal constraints"),
+    {AM_VOR, "voronoi", "Voronoi"},
+    {AM_NSCALE, "scale", "scaling"},
+    {AM_COMPRESS, "compress", "compress"},
+    {AM_VPSC, "vpsc", "vpsc"},
+    {AM_IPSEP, "ipsep", "ipsep"},
+    {AM_SCALE, "oscale", "old scaling"},
+    {AM_SCALEXY, "scalexy", "x and y scaling"},
+    {AM_ORTHO, "ortho", "orthogonal constraints"},
+    {AM_ORTHO_YX, "ortho_yx", "orthogonal constraints"},
+    {AM_ORTHOXY, "orthoxy", "xy orthogonal constraints"},
+    {AM_ORTHOYX, "orthoyx", "yx orthogonal constraints"},
+    {AM_PORTHO, "portho", "pseudo-orthogonal constraints"},
+    {AM_PORTHO_YX, "portho_yx", "pseudo-orthogonal constraints"},
+    {AM_PORTHOXY, "porthoxy", "xy pseudo-orthogonal constraints"},
+    {AM_PORTHOYX, "porthoyx", "yx pseudo-orthogonal constraints"},
 #if !((defined(HAVE_GTS) || defined(HAVE_TRIANGLE)) && defined(SFDP))
-    ITEM(AM_PRISM, "prism", 0),
+    {AM_PRISM, "prism", 0},
 #endif
-    {AM_NONE, 0, 0, 0}
+    {0}
 };
 
 /// Initialize and set prism values
-static void
-setPrismValues (Agraph_t* g, char* s, adjust_data* dp)
-{
+static void setPrismValues(Agraph_t *g, const char *s, adjust_data *dp) {
     int v;
 
     if (sscanf (s, "%d", &v) > 0 && v >= 0)
@@ -849,7 +828,7 @@ setPrismValues (Agraph_t* g, char* s, adjust_data* dp)
 }
 
 /// Convert string value to internal value of adjustment mode.
-static void getAdjustMode(Agraph_t *g, char *s, adjust_data *dp) {
+static void getAdjustMode(Agraph_t *g, const char *s, adjust_data *dp) {
     const lookup_t *ap = adjustMode + 1;
     if (s == NULL || *s == '\0') {
 	dp->mode = adjustMode[0].mode;
@@ -857,7 +836,11 @@ static void getAdjustMode(Agraph_t *g, char *s, adjust_data *dp) {
     }
     else {
 	while (ap->attrib) {
-	    if (!strncasecmp(s, ap->attrib, ap->len)) {
+	    bool matches = strcasecmp(s, ap->attrib) == 0;
+	    // "prism" takes parameters, so needs to match "prism.*"
+	    matches |= ap->mode == AM_PRISM
+	            && strncasecmp(s, ap->attrib, strlen(ap->attrib)) == 0;
+	    if (matches) {
 		if (ap->print == NULL) {
 		    agwarningf("Overlap value \"%s\" unsupported - ignored\n", ap->attrib);
 		    ap = &adjustMode[1];
@@ -865,7 +848,7 @@ static void getAdjustMode(Agraph_t *g, char *s, adjust_data *dp) {
 		dp->mode = ap->mode;
 		dp->print = ap->print;
 		if (ap->mode == AM_PRISM)
-		    setPrismValues (g, s + ap->len, dp);
+		    setPrismValues(g, s + strlen(ap->attrib), dp);
 		break;
 	    }
 	    ap++;
@@ -1000,25 +983,23 @@ removeOverlapWith (graph_t * G, adjust_data* am)
     /* create main array */
     if (makeInfo(G)) {
 	freeNodes();
-	free(sites);
-	sites = 0;
 	return nret;
     }
 
     /* establish and verify bounding box */
-    chkBoundBox(G);
+    state_t st = {0};
+    chkBoundBox(&st, G);
 
     if (am->mode == AM_SCALE)
-	ret = sAdjust();
+	ret = sAdjust(&st);
     else
-	ret = vAdjust();
+	ret = vAdjust(&st);
 
     if (ret)
 	updateGraph();
 
     freeNodes();
-    free(sites);
-    sites = 0;
+    free(st.sites);
 
     return ret+nret;
 }
