@@ -55,13 +55,13 @@ static void ideal_distance_avoid_overlap(int dim, SparseMatrix A, double *x, dou
 	} else if (dy < MACHINEACC*wy){
 	  t = wx/dx;
 	} else {
-	  t = MIN(wx/dx, wy/dy);
+	  t = fmin(wx / dx, wy / dy);
 	}
-	if (t > 1) t = MAX(t, 1.001);/* no point in things like t = 1.00000001 as this slow down convergence */
-	*tmax = MAX(*tmax, t);
-	*tmin = MIN(*tmin, t);
-	t = MIN(expandmax, t);
-	t = MAX(expandmin, t);
+	if (t > 1) t = fmax(t, 1.001);/* no point in things like t = 1.00000001 as this slow down convergence */
+	*tmax = fmax(*tmax, t);
+	*tmin = fmin(*tmin, t);
+	t = fmin(expandmax, t);
+	t = fmax(expandmin, t);
 	if (t > 1) {
 	  ideal_distance[j] = t*dist;
 	} else {
@@ -75,14 +75,11 @@ static void ideal_distance_avoid_overlap(int dim, SparseMatrix A, double *x, dou
 
 enum {INTV_OPEN, INTV_CLOSE};
 
-struct scan_point_struct{
+typedef struct {
   int node;
   double x;
   int status;
-};
-
-typedef struct scan_point_struct scan_point;
-
+} scan_point;
 
 static int comp_scan_points(const void *p, const void *q){
   const scan_point *pp = p;
@@ -107,20 +104,11 @@ static void NodeDest(void* a) {
   /*  free((int*)a);*/
 }
 
-static int NodeComp(const void* a,const void* b) {
-  return comp_scan_points(a,b);
-
-}
-
-static void InfoDest(void *a){
-  (void)a;
-}
-
 static SparseMatrix get_overlap_graph(int dim, int n, double *x, double *width, int check_overlap_only){
   /* if check_overlap_only = TRUE, we only check whether there is one overlap */
   int i, k, neighbor;
   SparseMatrix A = NULL, B = NULL;
-  rb_red_blk_node *newNode, *newNode0, *newNode2 = NULL;
+  rb_red_blk_node *newNode, *newNode0;
   rb_red_blk_tree* treey;
   double one = 1;
 
@@ -147,7 +135,7 @@ static SparseMatrix get_overlap_graph(int dim, int n, double *x, double *width,
     scanpointsy[i+n].status = INTV_CLOSE;
   }
 
-  treey = RBTreeCreate(NodeComp, NodeDest, InfoDest);
+  treey = RBTreeCreate(comp_scan_points, NodeDest);
 
   for (i = 0; i < 2*n; i++){
 #ifdef DEBUG_RBTREE
@@ -163,14 +151,14 @@ static SparseMatrix get_overlap_graph(int dim, int n, double *x, double *width,
       treey->PrintKey(&(scanpointsy[k]));
 #endif
 
-      RBTreeInsert(treey, &(scanpointsy[k]), NULL); /* add both open and close int for y */
+      RBTreeInsert(treey, &scanpointsy[k]); // add both open and close int for y
 
 #ifdef DEBUG_RBTREE
       fprintf(stderr, "inserting2...");
       treey->PrintKey(&(scanpointsy[k+n]));
 #endif
 
-      RBTreeInsert(treey, &(scanpointsy[k+n]), NULL);
+      RBTreeInsert(treey, &scanpointsy[k + n]);
     } else {
       double bsta, bbsta, bsto, bbsto; int ii; 
 
@@ -182,7 +170,7 @@ static SparseMatrix get_overlap_graph(int dim, int n, double *x, double *width,
       bsta = scanpointsy[ii].x; bsto = scanpointsy[ii+n].x;
 
 #ifdef DEBUG_RBTREE
-      fprintf(stderr, "poping..%d....yinterval={%f,%f}\n", scanpointsy[k + n].node, bsta, bsto);
+      fprintf(stderr, "popping..%d....yinterval={%f,%f}\n", scanpointsy[k + n].node, bsta, bsto);
       treey->PrintKey(newNode->key);
 #endif
 
@@ -201,30 +189,15 @@ static SparseMatrix get_overlap_graph(int dim, int n, double *x, double *width,
 #endif
 	    if (check_overlap_only) goto check_overlap_RETURN;
 	  }
-	} else {
-	  newNode2 = newNode;
 	}
-
       }
 
 #ifdef DEBUG_RBTREE
-      fprintf(stderr, "deleteing...");
+      fprintf(stderr, "deleting...");
       treey->PrintKey(newNode0->key);
 #endif
 
       if (newNode0) RBDelete(treey,newNode0);
-
-
-     if (newNode2 && newNode2 != treey->nil && newNode2 != newNode0) {
-
-#ifdef DEBUG_RBTREE
-	fprintf(stderr, "deleteing2...");
-	treey->PrintKey(newNode2->key);
-#endif
-
-	if (newNode0) RBDelete(treey,newNode2);
-      }
-
     }
   }
 
@@ -252,7 +225,7 @@ static void relative_position_constraints_delete(void *d){
   free(data->irn);
   free(data->jcn);
   free(data->val);
-  /* other stuff inside relative_position_constraints is assed back to the user hence no need to deallocator*/
+  /* other stuff inside relative_position_constraints is passed back to the user hence no need to deallocator*/
   free(d);
 }
 
@@ -375,7 +348,7 @@ OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m,
   }
 
   sm->tol_cg = 0.01;
-  sm->maxit_cg = sqrt((double) A->m);
+  sm->maxit_cg = floor(sqrt(A->m));
 
   sm->lambda = gv_calloc(m, sizeof(double));
   
@@ -392,15 +365,6 @@ OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m,
   sm->Lw = B;
   sm->Lwd = SparseMatrix_copy(sm->Lw);
 
-#ifdef DEBUG
-  {
-    FILE *fp;
-    fp = fopen("/tmp/111","w");
-    export_embedding(fp, dim, sm->Lwd, x, NULL);
-    fclose(fp);
-  }
-#endif
-
   if (!(sm->Lw) || !(sm->Lwd)) {
     OverlapSmoother_delete(sm);
     return NULL;
@@ -412,7 +376,8 @@ OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m,
 
   /* no overlap at all! */
   if (*max_overlap < 1 && shrink){
-    double scale_sta = MIN(1, *max_overlap*1.0001), scale_sto = 1;
+    double scale_sta = fmin(1, *max_overlap * 1.0001);
+    const double scale_sto = 1;
 
     if (Verbose) fprintf(stderr," no overlap (overlap = %f), rescale to shrink\n", *max_overlap - 1);
 
@@ -465,14 +430,7 @@ void OverlapSmoother_delete(OverlapSmoother sm){
 double OverlapSmoother_smooth(OverlapSmoother sm, int dim, double *x){
   int maxit_sm = 1;/* only using 1 iteration of stress majorization 
 		      is found to give better results and save time! */
-  double res = StressMajorizationSmoother_smooth(sm, dim, x, maxit_sm);
-#ifdef DEBUG
-  {FILE *fp;
-  fp = fopen("/tmp/222","w");
-  export_embedding(fp, dim, sm->Lwd, x, NULL);
-  fclose(fp);}
-#endif
-  return res;
+  return StressMajorizationSmoother_smooth(sm, dim, x, maxit_sm);
 }
 
 /*================================= end OverlapSmoother =============*/
@@ -486,7 +444,7 @@ static void scale_to_edge_length(int dim, SparseMatrix A, double *x, double avg_
   if (Verbose) fprintf(stderr,"avg edge len=%f avg_label-size= %f\n", dist, avg_label_size);
 
 
-  dist = avg_label_size/MAX(dist, MACHINEACC);
+  dist = avg_label_size / fmax(dist, MACHINEACC);
 
   for (i = 0; i < dim*A->m; i++) x[i] *= dist;
 }
@@ -501,8 +459,8 @@ static void print_bounding_box(int n, int dim, double *x){
 
   for (i = 0; i < n; i++){
     for (k = 0; k < dim; k++){
-      xmin[k] = MIN(xmin[k],x[i*dim+k]);
-      xmax[k] = MAX(xmax[k],x[i*dim+k]);
+      xmin[k] = fmin(xmin[k], x[i * dim + k]);
+      xmax[k] = fmax(xmax[k], x[i * dim + k]);
     }
   }
   fprintf(stderr,"bounding box = \n");
@@ -566,13 +524,6 @@ void remove_overlap(int dim, SparseMatrix A, double *x, double *label_sizes, int
 
 #ifdef DEBUG
   _statistics[0] = _statistics[1] = 0.;
-  {FILE*fp;
-  fp = fopen("x1","w");
-  for (i = 0; i < A->m; i++){
-    fprintf(fp, "%f %f\n",x[i*2],x[i*2+1]);
-  }
-  fclose(fp);
-  }
 #endif
 
   bool has_penalty_terms =
@@ -620,23 +571,8 @@ void remove_overlap(int dim, SparseMatrix A, double *x, double *label_sizes, int
 #ifdef DEBUG
   fprintf(stderr," number of cg iter = %f, number of stress majorization iter = %f number of overlap removal try = %d\n",
 	  _statistics[0], _statistics[1], i - 1);
-
-  {FILE*fp;
-  fp = fopen("x2","w");
-  for (i = 0; i < A->m; i++){
-    fprintf(fp, "%f %f\n",x[i*2],x[i*2+1]);
-  }
-  fclose(fp);
-  }
 #endif
 
-#ifdef DEBUG
-  {FILE*fp;
-  fp = fopen("/tmp/m","w");
-  if (A) export_embedding(fp, dim, A, x, label_sizes);
-  fclose(fp);
-  }
-#endif
 #ifdef TIME
   fprintf(stderr, "post processing %f\n",((double) (clock() - cpu)) / CLOCKS_PER_SEC);
 #endif
