@@ -23,6 +23,8 @@
 
 #define DEBUG
 #include <assert.h>
+#include <float.h>
+#include <math.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <ortho/maze.h>
@@ -252,17 +254,15 @@ typedef struct {
     Dt_t*     chans;
 } chanItem;
 
-static void freeChannel(channel *cp, Dtdisc_t *disc) {
-    (void)disc;
-
+static void freeChannel(void *chan) {
+    channel *cp = chan;
     free_graph (cp->G);
     seg_list_free(&cp->seg_list);
     free (cp);
 }
 
-static void freeChanItem(chanItem *cp, Dtdisc_t *disc) {
-    (void)disc;
-
+static void freeChanItem(void *item) {
+    chanItem *cp = item;
     dtclose (cp->chans);
     free (cp);
 }
@@ -276,12 +276,9 @@ static void freeChanItem(chanItem *cp, Dtdisc_t *disc) {
  * When searching for a channel containing a segment, we rely on
  * interval containment to return the correct channel.
  */
-static int
-chancmpid(Dt_t* d, paird* key1, paird* key2, Dtdisc_t* disc)
-{
-  (void)d;
-  (void)disc;
-
+static int chancmpid(void *k1, void *k2) {
+  const paird *key1 = k1;
+  const paird *key2 = k2;
   if (key1->p1 > key2->p1) {
     if (key1->p2 <= key2->p2) return 0;
     else return 1;
@@ -293,12 +290,9 @@ chancmpid(Dt_t* d, paird* key1, paird* key2, Dtdisc_t* disc)
   else return 0;
 }   
 
-static int
-dcmpid(Dt_t* d, double* key1, double* key2, Dtdisc_t* disc)
-{
-  (void)d;
-  (void)disc;
-
+static int dcmpid(void *k1, void *k2) {
+  const double *key1 = k1;
+  const double *key2 = k2;
   if (*key1 > *key2) return 1;
   else if (*key1 < *key2) return -1;
   else return 0;
@@ -309,8 +303,8 @@ static Dtdisc_t chanDisc = {
     sizeof(paird),
     offsetof(channel,link),
     0,
-    (Dtfree_f)freeChannel,
-    (Dtcompar_f)chancmpid,
+    freeChannel,
+    chancmpid,
 };
 
 static Dtdisc_t chanItemDisc = {
@@ -318,8 +312,8 @@ static Dtdisc_t chanItemDisc = {
     sizeof(double),
     offsetof(chanItem,link),
     0,
-    (Dtfree_f)freeChanItem,
-    (Dtcompar_f)dcmpid,
+    freeChanItem,
+    dcmpid,
 };
 
 static void
@@ -529,12 +523,12 @@ static void putSeg (FILE* fp, segment* seg)
       seg->p.p2, seg->comm_coord, bendToStr (seg->l1), bendToStr (seg->l2));
 }
 
-static DEBUG_FN void dumpChanG(channel *cp, int v) {
+static DEBUG_FN void dumpChanG(channel *cp, double v) {
   intitem* ip;
   Dt_t* adj;
 
   if (seg_list_size(&cp->seg_list) < 2) return;
-  fprintf (stderr, "channel %d (%f,%f)\n", v, cp->p.p1, cp->p.p2);
+  fprintf (stderr, "channel %.0f (%f,%f)\n", v, cp->p.p1, cp->p.p2);
   for (size_t k = 0; k < seg_list_size(&cp->seg_list); ++k) {
     adj = cp->G->vertices[k].adj_list;
     if (dtsize(adj) == 0) continue;
@@ -1118,9 +1112,7 @@ vtrack (segment* seg, maze* m)
   return left + f*(right-left);
 }
 
-static int
-htrack (segment* seg, maze* m)
-{
+static double htrack(segment *seg, maze *m) {
   channel* chp = chanSearch(m->hchans, seg);
   double f = 1.0 - (double)seg->track_no / ((double)seg_list_size(&chp->seg_list) + 1);
   double lo = chp->cp->bb.LL.y;
@@ -1414,10 +1406,8 @@ static char* epilog2 =
 %%%%Trailer\n\
 %%%%BoundingBox: %.f %.f %.f %.f\n";
 
-static point
-coordOf (cell* cp, snode* np)
-{
-    point p;
+static pointf coordOf(cell *cp, snode *np) {
+    pointf p;
     if (cp->sides[M_TOP] == np) {
 	p.x = (cp->bb.LL.x + cp->bb.UR.x)/2;
 	p.y = cp->bb.UR.y;
@@ -1444,7 +1434,7 @@ coordOf (cell* cp, snode* np)
 static boxf
 emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
 {
-    int x, y;
+    double x, y;
     boxf n = CELL(agtail(e))->bb;
     segment* seg = rte.segs;
     if (seg->isVert) {
@@ -1455,11 +1445,11 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
 	y = htrack(seg, m);
 	x = (n.UR.x + n.LL.x)/2;
     }
-    bb.LL.x = MIN(bb.LL.x, SC*x);
-    bb.LL.y = MIN(bb.LL.y, SC*y);
-    bb.UR.x = MAX(bb.UR.x, SC*x);
-    bb.UR.y = MAX(bb.UR.y, SC*y);
-    fprintf (fp, "newpath %d %d moveto\n", SC*x, SC*y);
+    bb.LL.x = fmin(bb.LL.x, SC * x);
+    bb.LL.y = fmin(bb.LL.y, SC * y);
+    bb.UR.x = fmax(bb.UR.x, SC * x);
+    bb.UR.y = fmax(bb.UR.y, SC * y);
+    fprintf(fp, "newpath %.0f %.0f moveto\n", SC * x, SC * y);
 
     for (size_t i = 1;i<rte.n;i++) {
 	seg = rte.segs+i;
@@ -1469,11 +1459,11 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
 	else {
 	    y = htrack(seg, m);
 	}
-	bb.LL.x = MIN(bb.LL.x, SC*x);
-	bb.LL.y = MIN(bb.LL.y, SC*y);
-	bb.UR.x = MAX(bb.UR.x, SC*x);
-	bb.UR.y = MAX(bb.UR.y, SC*y);
-	fprintf (fp, "%d %d lineto\n", SC*x, SC*y);
+	bb.LL.x = fmin(bb.LL.x, SC * x);
+	bb.LL.y = fmin(bb.LL.y, SC * y);
+	bb.UR.x = fmax(bb.UR.x, SC * x);
+	bb.UR.y = fmax(bb.UR.y, SC * y);
+	fprintf(fp, "%.0f %.0f lineto\n", SC * x, SC * y);
     }
 
     n = CELL(aghead(e))->bb;
@@ -1485,11 +1475,11 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
 	y = htrack(seg, m);
 	x = (n.LL.x + n.UR.x)/2;
     }
-    bb.LL.x = MIN(bb.LL.x, SC*x);
-    bb.LL.y = MIN(bb.LL.y, SC*y);
-    bb.UR.x = MAX(bb.UR.x, SC*x);
-    bb.UR.y = MAX(bb.UR.y, SC*y);
-    fprintf (fp, "%d %d lineto stroke\n", SC*x, SC*y);
+    bb.LL.x = fmin(bb.LL.x, SC * x);
+    bb.LL.y = fmin(bb.LL.y, SC * y);
+    bb.UR.x = fmax(bb.UR.x, SC * x);
+    bb.UR.y = fmax(bb.UR.y, SC * y);
+    fprintf(fp, "%.0f %.0f lineto stroke\n", SC * x, SC * y);
 
     return bb;
 }
@@ -1508,7 +1498,7 @@ static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg) {
     cell* cp;
     snode* np;
     sedge* ep;
-    point p;
+    pointf p;
     int i;
     fputs ("graph G {\n", fp);
     fputs (" node[shape=point]\n", fp);
@@ -1517,15 +1507,13 @@ static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg) {
 	np = sg->nodes+i;
 	cp = np->cells[0];
 	if (cp == np->cells[1]) {
-	    pointf pf = midPt (cp);
-	    p.x = pf.x;
-	    p.y = pf.y;
+	    p = midPt(cp);
 	}
 	else {
 	    if (IsNode(cp)) cp = np->cells[1];
 	    p = coordOf (cp, np);
 	}
-	fprintf (fp, "  %d [pos=\"%d,%d!\"]\n", i, p.x, p.y);
+	fprintf (fp, "  %d [pos=\"%.0f,%.0f!\"]\n", i, p.x, p.y);
     }
     for (i = 0; i < sg->nedges; i++) {
 	ep = sg->edges+i;
@@ -1536,8 +1524,8 @@ static DEBUG_FN void emitSearchGraph(FILE *fp, sgraph *sg) {
 
 static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
                                route *route_list, epair_t es[]) {
-    boxf absbb = {.LL = {.x = MAXDOUBLE, .y = MAXDOUBLE},
-                  .UR = {.x = -MAXDOUBLE, .y = -MAXDOUBLE}};
+    boxf absbb = {.LL = {.x = DBL_MAX, .y = DBL_MAX},
+                  .UR = {.x = -DBL_MAX, .y = -DBL_MAX}};
 
     fprintf (fp, "%s", prolog2);
     fprintf (fp, "%d %d translate\n", TRANS, TRANS);
@@ -1556,10 +1544,10 @@ static DEBUG_FN void emitGraph(FILE *fp, maze *mp, size_t n_edges,
     for (int i = 0; i < mp->ncells; i++) {
       const boxf bb = mp->cells[i].bb;
       fprintf (fp, "%f %f %f %f cell\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
-      absbb.LL.x = MIN(absbb.LL.x, bb.LL.x);
-      absbb.LL.y = MIN(absbb.LL.y, bb.LL.y);
-      absbb.UR.x = MAX(absbb.UR.x, bb.UR.x);
-      absbb.UR.y = MAX(absbb.UR.y, bb.UR.y);
+      absbb.LL.x = fmin(absbb.LL.x, bb.LL.x);
+      absbb.LL.y = fmin(absbb.LL.y, bb.LL.y);
+      absbb.UR.x = fmax(absbb.UR.x, bb.UR.x);
+      absbb.UR.y = fmax(absbb.UR.y, bb.UR.y);
     }
 
     const boxf bbox = {
