@@ -640,15 +640,13 @@ monotonate_trapezoids(int nsegs, segment_t *seg, traps_t *tr,
     free (mon);
 }
 
-static bool
-rectIntersect (boxf *d, const boxf *r0, const boxf *r1)
-{
-    double t = fmax(r0->LL.x, r1->LL.x);
-    d->UR.x = fmin(r0->UR.x, r1->UR.x);
+static bool rectIntersect(boxf *d, const boxf r0, const boxf r1) {
+    double t = fmax(r0.LL.x, r1.LL.x);
+    d->UR.x = fmin(r0.UR.x, r1.UR.x);
     d->LL.x = t;
     
-    t = fmax(r0->LL.y, r1->LL.y);
-    d->UR.y = fmin(r0->UR.y, r1->UR.y);
+    t = fmax(r0.LL.y, r1.LL.y);
+    d->UR.y = fmin(r0.UR.y, r1.UR.y);
     d->LL.y = t;
 
     return !(d->LL.x >= d->UR.x || d->LL.y >= d->UR.y);
@@ -722,10 +720,11 @@ boxf *partition(cell *cells, int ncells, size_t *nrects, boxf bb) {
     free(ver_traps.data);
 
     boxes_t rs = {0};
-    for (size_t i = 0; i < vert_decomp.size; ++i)
-	for (size_t j = 0; j < hor_decomp.size; ++j) {
+    for (size_t i = 0; i < boxes_size(&vert_decomp); ++i)
+	for (size_t j = 0; j < boxes_size(&hor_decomp); ++j) {
 	    boxf newbox = {0};
-	    if (rectIntersect(&newbox, &vert_decomp.data[i], &hor_decomp.data[j]))
+	    if (rectIntersect(&newbox, boxes_get(&vert_decomp, i),
+	                      boxes_get(&hor_decomp, j)))
 		boxes_append(&rs, newbox);
 	}
 
@@ -733,6 +732,6 @@ boxf *partition(cell *cells, int ncells, size_t *nrects, boxf bb) {
     free (permute);
     boxes_free(&hor_decomp);
     boxes_free(&vert_decomp);
-    *nrects = rs.size;
-    return rs.data;
+    *nrects = boxes_size(&rs);
+    return boxes_detach(&rs);
 }
