@@ -20,12 +20,12 @@
 #include <cgraph/prisize_t.h>
 #include <cgraph/sort.h>
 #include <cgraph/startswith.h>
-#include <cgraph/streq.h>
 #include <common/render.h>
 #include <pack/pack.h>
 #include <common/pointset.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/streq.h>
 
 #define C 100			/* Max. avg. polyomino size */
 
@@ -228,10 +228,10 @@ static void genBox(boxf bb0, ginfo *info, int ssize, unsigned int margin,
     PointSet *ps;
     int W, H;
     pointf UR, LL;
-    boxf bb;
     double x, y;
 
-    bb = bb0;
+    const boxf bb = {.LL = {.x = round(bb0.LL.x), .y = round(bb0.LL.y)},
+                     .UR = {.x = round(bb0.UR.x), .y = round(bb0.UR.y)}};
     ps = newPS();
 
     LL.x = center.x - margin;
@@ -239,7 +239,9 @@ static void genBox(boxf bb0, ginfo *info, int ssize, unsigned int margin,
     UR.x = center.x + bb.UR.x - bb.LL.x + margin;
     UR.y = center.y + bb.UR.y - bb.LL.y + margin;
     CELL(LL, ssize);
+    LL = (pointf){.x = round(LL.x), .y = round(LL.y)};
     CELL(UR, ssize);
+    UR = (pointf){.x = round(UR.x), .y = round(UR.y)};
 
     for (x = LL.x; x <= UR.x; x++)
 	for (y = LL.y; y <= UR.y; y++)
@@ -305,7 +307,10 @@ static int genPoly(Agraph_t *root, Agraph_t *g, ginfo *info, int ssize,
 	/* do bbox of top clusters */
 	for (i = 1; i <= GD_n_cluster(g); i++) {
 	    subg = GD_clust(g)[i];
-	    boxf bb = GD_bb(subg);
+	    boxf bb = {.LL = {.x = round(GD_bb(subg).LL.x),
+	                      .y = round(GD_bb(subg).LL.y)},
+	               .UR = {.x = round(GD_bb(subg).UR.x),
+	                      .y = round(GD_bb(subg).UR.y)}};
 	    if (bb.UR.x > bb.LL.x && bb.UR.y > bb.LL.y) {
 		MOVEPT(bb.LL);
 		MOVEPT(bb.UR);
@@ -314,7 +319,9 @@ static int genPoly(Agraph_t *root, Agraph_t *g, ginfo *info, int ssize,
 		bb.UR.x += margin;
 		bb.UR.y += margin;
 		CELL(bb.LL, ssize);
+		bb.LL = (pointf){.x = round(bb.LL.x), .y = round(bb.LL.y)};
 		CELL(bb.UR, ssize);
+		bb.UR = (pointf){.x = round(bb.UR.x), .y = round(bb.UR.y)};
 
 		for (double x = bb.LL.x; x <= bb.UR.x; x++)
 		    for (double y = bb.LL.y; y <= bb.UR.y; y++)
@@ -328,26 +335,31 @@ static int genPoly(Agraph_t *root, Agraph_t *g, ginfo *info, int ssize,
 
 	/* now do remaining nodes and edges */
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    pointf pt = coord(n);
+	    const pointf ptf = coord(n);
+	    pointf pt = {.x = round(ptf.x), .y = round(ptf.y)};
 	    MOVEPT(pt);
 	    if (!ND_clust(n)) {	/* n is not in a top-level cluster */
-		const pointf s2 = {.x = margin + ND_xsize(n) / 2,
-		                   .y = margin + ND_ysize(n) / 2};
+		const pointf s2 = {.x = round(margin + ND_xsize(n) / 2),
+		                   .y = round(margin + ND_ysize(n) / 2)};
 		pointf LL = sub_pointf(pt, s2);
 		pointf UR = add_pointf(pt, s2);
 		CELL(LL, ssize);
+		LL = (pointf){.x = round(LL.x), .y = round(LL.y)};
 		CELL(UR, ssize);
+		UR = (pointf){.x = round(UR.x), .y = round(UR.y)};
 
 		for (double x = LL.x; x <= UR.x; x++)
 		    for (double y = LL.y; y <= UR.y; y++)
 			addPS(ps, x, y);
 
 		CELL(pt, ssize);
+		pt = (pointf){.x = round(pt.x), .y = round(pt.y)};
 		for (e = agfstout(eg, n); e; e = agnxtout(eg, e)) {
 		    fillEdge(e, pt, ps, dx, dy, ssize, doSplines);
 		}
 	    } else {
 		CELL(pt, ssize);
+		pt = (pointf){.x = round(pt.x), .y = round(pt.y)};
 		for (e = agfstout(eg, n); e; e = agnxtout(eg, e)) {
 		    if (ND_clust(n) == ND_clust(aghead(e)))
 			continue;
@@ -364,20 +376,24 @@ static int genPoly(Agraph_t *root, Agraph_t *g, ginfo *info, int ssize,
 
     } else
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    pointf pt = coord(n);
+	    const pointf ptf = coord(n);
+	    pointf pt = {.x = round(ptf.x), .y = round(ptf.y)};
 	    MOVEPT(pt);
-	    pointf s2 = {.x = margin + ND_xsize(n) / 2,
-	                 .y = margin + ND_ysize(n) / 2};
+	    pointf s2 = {.x = round(margin + ND_xsize(n) / 2),
+	                 .y = round(margin + ND_ysize(n) / 2)};
 	    pointf LL = sub_pointf(pt, s2);
 	    pointf UR = add_pointf(pt, s2);
 	    CELL(LL, ssize);
+	    LL = (pointf){.x = round(LL.x), .y = round(LL.y)};
 	    CELL(UR, ssize);
+	    UR = (pointf){.x = round(UR.x), .y = round(UR.y)};
 
 	    for (double x = LL.x; x <= UR.x; x++)
 		for (double y = LL.y; y <= UR.y; y++)
 		    addPS(ps, x, y);
 
 	    CELL(pt, ssize);
+	    pt = (pointf){.x = round(pt.x), .y = round(pt.y)};
 	    for (e = agfstout(eg, n); e; e = agnxtout(eg, e)) {
 		fillEdge(e, pt, ps, dx, dy, ssize, doSplines);
 	    }
@@ -420,7 +436,8 @@ static int fits(int x, int y, ginfo *info, PointSet *ps, pointf *place,
 	cells++;
     }
 
-    const pointf LL = bbs[info->index].LL;
+    const pointf LL = {.x = round(bbs[info->index].LL.x),
+                       .y = round(bbs[info->index].LL.y)};
     place->x = step * x - LL.x;
     place->y = step * y - LL.y;
 
@@ -659,17 +676,19 @@ static pointf *arrayRects(size_t ng, boxf *gs, pack_info *pinfo) {
 	const size_t idx = ip->index;
 	bb = gs[idx];
 	if (pinfo->flags & PK_LEFT_ALIGN)
-	    places[idx].x = widths[c];
+	    places[idx].x = round(widths[c]);
 	else if (pinfo->flags & PK_RIGHT_ALIGN)
-	    places[idx].x = widths[c+1] - (bb.UR.x - bb.LL.x);
+	    places[idx].x = round(widths[c + 1] - (bb.UR.x - bb.LL.x));
 	else
-	    places[idx].x = (widths[c] + widths[c+1] - bb.UR.x - bb.LL.x)/2.0;
+	    places[idx].x =
+	      round((widths[c] + widths[c + 1] - bb.UR.x - bb.LL.x) / 2.0);
 	if (pinfo->flags & PK_TOP_ALIGN)
-	    places[idx].y = heights[r] - (bb.UR.y - bb.LL.y);
+	    places[idx].y = round(heights[r] - (bb.UR.y - bb.LL.y));
 	else if (pinfo->flags & PK_BOT_ALIGN)
-	    places[idx].y = heights[r+1];
+	    places[idx].y = round(heights[r + 1]);
 	else
-	    places[idx].y = (heights[r] + heights[r+1] - bb.UR.y - bb.LL.y)/2.0;
+	    places[idx].y =
+	      round((heights[r] + heights[r + 1] - bb.UR.y - bb.LL.y) / 2.0);
 	INC(rowMajor,c,r);
     }
 
@@ -767,7 +786,10 @@ static pointf *polyGraphs(size_t ng, Agraph_t **gs, Agraph_t *root,
 	Agraph_t *g = gs[i];
 	compute_bb(g);
 	if (fixed && fixed[i]) {
-	    const boxf bb = GD_bb(g);
+	    const boxf bb = {.LL = {.x = round(GD_bb(g).LL.x),
+	                            .y = round(GD_bb(g).LL.y)},
+	                     .UR = {.x = round(GD_bb(g).UR.x),
+	                            .y = round(GD_bb(g).UR.y)}};
 	    if (fixed_cnt) {
 		fixed_bb.LL.x = fmin(bb.LL.x, fixed_bb.LL.x);
 		fixed_bb.LL.y = fmin(bb.LL.y, fixed_bb.LL.y);
@@ -799,7 +821,8 @@ static pointf *polyGraphs(size_t ng, Agraph_t **gs, Agraph_t *root,
     /* generate polyomino cover for the graphs */
     pointf center = {0};
     if (fixed) {
-	center = mid_pointf(fixed_bb.LL, fixed_bb.UR);
+	center.x = round((fixed_bb.LL.x + fixed_bb.UR.x) / 2);
+	center.y = round((fixed_bb.LL.y + fixed_bb.UR.y) / 2);
     }
     info = gv_calloc(ng, sizeof(ginfo));
     for (size_t i = 0; i < ng; i++) {
