@@ -24,12 +24,12 @@
 #include <gvc/gvplugin_device.h>
 #include <cgraph/alloc.h>
 #include <cgraph/startswith.h>
-#include <cgraph/streq.h>
 #include <cgraph/unreachable.h>
 #include <common/utils.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 #include <gvc/gvcint.h>
+#include <util/streq.h>
 
 typedef enum {
 	FORMAT_JSON,
@@ -612,9 +612,9 @@ static Dtdisc_t intDisc = {
     offsetof(intm, id),
     -1,
     offsetof(intm, link),
-    (Dtmake_f) NULL,
+    NULL,
     freef,
-    (Dtcompar_f) NULL,
+    NULL,
 };
 
 static int lookup (Dt_t* map, char* name)
