@@ -11,7 +11,7 @@ sys.path.append(os.path.dirname(__file__))
 from gvtest import run_c  # pylint: disable=wrong-import-position
 
 
-@pytest.mark.parametrize("utility", ("bitarray", "list", "stack", "tokenize"))
+@pytest.mark.parametrize("utility", ("bitarray", "list", "tokenize"))
 def test_utility(utility: str):
     """run the given utility’s unit tests"""
 
